"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class OfflineServingQueryOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INCLUDE_FEATURESET_VERSION_COLUMN_FIELD_NUMBER: builtins.int
    include_featureset_version_column: builtins.bool
    """Whether or not to include featureset version as a column in the result set"""
    def __init__(
        self,
        *,
        include_featureset_version_column: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["include_featureset_version_column", b"include_featureset_version_column"]) -> None: ...

global___OfflineServingQueryOptions = OfflineServingQueryOptions
