"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ModelRepositoryJFrogSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JFROG_PROJECT_KEY_FIELD_NUMBER: builtins.int
    jfrog_project_key: builtins.str
    """JFrog project key"""
    def __init__(
        self,
        *,
        jfrog_project_key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["jfrog_project_identifier", b"jfrog_project_identifier", "jfrog_project_key", b"jfrog_project_key"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["jfrog_project_identifier", b"jfrog_project_identifier", "jfrog_project_key", b"jfrog_project_key"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["jfrog_project_identifier", b"jfrog_project_identifier"]) -> typing_extensions.Literal["jfrog_project_key"] | None: ...

global___ModelRepositoryJFrogSpec = ModelRepositoryJFrogSpec
