# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/integration/pagerduty_integration.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,qwak/integration/pagerduty_integration.proto\x12\x1bqwak.integration.management\"\xf4\x01\n\x14PagerdutyIntegration\x12]\n\x1f\x65ncrypted_pagerduty_auth_config\x18\x01 \x01(\x0b\x32\x30.qwak.integration.management.PagerdutyAuthConfigB\x02\x18\x01\x12\x14\n\x0c\x65ndpoint_url\x18\x02 \x01(\t\x12_\n\x17pagerduty_system_secret\x18\x03 \x01(\x0b\x32<.qwak.integration.management.PagerdutySystemSecretDescriptorH\x00\x42\x06\n\x04\x61uth\"|\n\x18PagerdutyIntegrationSpec\x12X\n\x1cpagerduty_auth_configuration\x18\x01 \x01(\x0b\x32\x30.qwak.integration.management.PagerdutyAuthConfigH\x00\x42\x06\n\x04\x61uth\"\xd3\x01\n\x13PagerdutyAuthConfig\x12Y\n\x15\x65vents_v1_auth_config\x18\x01 \x01(\x0b\x32\x38.qwak.integration.management.PagerdutyEventsV1AuthConfigH\x00\x12Y\n\x15\x65vents_v2_auth_config\x18\x02 \x01(\x0b\x32\x38.qwak.integration.management.PagerdutyEventsV2AuthConfigH\x00\x42\x06\n\x04\x61uth\"2\n\x1bPagerdutyEventsV1AuthConfig\x12\x13\n\x0bservice_key\x18\x01 \x01(\t\"2\n\x1bPagerdutyEventsV2AuthConfig\x12\x13\n\x0brouting_key\x18\x01 \x01(\t\"\xb0\x02\n\x1fPagerdutySystemSecretDescriptor\x12\x13\n\x0bsecret_name\x18\x01 \x01(\t\x12q\n!pagerduty_events_v1_system_secret\x18\x02 \x01(\x0b\x32\x44.qwak.integration.management.PagerdutyEventsV1SystemSecretDescriptorH\x00\x12q\n!pagerduty_events_v2_system_secret\x18\x03 \x01(\x0b\x32\x44.qwak.integration.management.PagerdutyEventsV2SystemSecretDescriptorH\x00\x42\x12\n\x10pagerduty_secret\"I\n\'PagerdutyEventsV1SystemSecretDescriptor\x12\x1e\n\x16service_key_secret_key\x18\x01 \x01(\t\"I\n\'PagerdutyEventsV2SystemSecretDescriptor\x12\x1e\n\x16routing_key_secret_key\x18\x01 \x01(\t\"j\n\x17PagerdutyValidationSpec\x12O\n\x15pagerduty_auth_config\x18\x01 \x01(\x0b\x32\x30.qwak.integration.management.PagerdutyAuthConfig\"\x1d\n\x1bPagerdutyIntegrationOptionsBH\n&com.qwak.ai.management.integration.apiP\x01Z\x1cqwak/integration;integrationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.integration.pagerduty_integration_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&com.qwak.ai.management.integration.apiP\001Z\034qwak/integration;integration'
  _PAGERDUTYINTEGRATION.fields_by_name['encrypted_pagerduty_auth_config']._options = None
  _PAGERDUTYINTEGRATION.fields_by_name['encrypted_pagerduty_auth_config']._serialized_options = b'\030\001'
  _globals['_PAGERDUTYINTEGRATION']._serialized_start=78
  _globals['_PAGERDUTYINTEGRATION']._serialized_end=322
  _globals['_PAGERDUTYINTEGRATIONSPEC']._serialized_start=324
  _globals['_PAGERDUTYINTEGRATIONSPEC']._serialized_end=448
  _globals['_PAGERDUTYAUTHCONFIG']._serialized_start=451
  _globals['_PAGERDUTYAUTHCONFIG']._serialized_end=662
  _globals['_PAGERDUTYEVENTSV1AUTHCONFIG']._serialized_start=664
  _globals['_PAGERDUTYEVENTSV1AUTHCONFIG']._serialized_end=714
  _globals['_PAGERDUTYEVENTSV2AUTHCONFIG']._serialized_start=716
  _globals['_PAGERDUTYEVENTSV2AUTHCONFIG']._serialized_end=766
  _globals['_PAGERDUTYSYSTEMSECRETDESCRIPTOR']._serialized_start=769
  _globals['_PAGERDUTYSYSTEMSECRETDESCRIPTOR']._serialized_end=1073
  _globals['_PAGERDUTYEVENTSV1SYSTEMSECRETDESCRIPTOR']._serialized_start=1075
  _globals['_PAGERDUTYEVENTSV1SYSTEMSECRETDESCRIPTOR']._serialized_end=1148
  _globals['_PAGERDUTYEVENTSV2SYSTEMSECRETDESCRIPTOR']._serialized_start=1150
  _globals['_PAGERDUTYEVENTSV2SYSTEMSECRETDESCRIPTOR']._serialized_end=1223
  _globals['_PAGERDUTYVALIDATIONSPEC']._serialized_start=1225
  _globals['_PAGERDUTYVALIDATIONSPEC']._serialized_end=1331
  _globals['_PAGERDUTYINTEGRATIONOPTIONS']._serialized_start=1333
  _globals['_PAGERDUTYINTEGRATIONOPTIONS']._serialized_end=1362
# @@protoc_insertion_point(module_scope)
