# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/kube_deployment_captain/batch_job.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,qwak/kube_deployment_captain/batch_job.proto\x12\x1cqwak.kube.deployment.captain\x1a\x1egoogle/protobuf/wrappers.proto\"\xd2\x03\n\x1cListInferenceJobFilesRequest\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x16\n\x0e\x64irectory_path\x18\x02 \x01(\t\x12\x18\n\x0ctoken_secret\x18\x03 \x01(\tB\x02\x18\x01\x12\x19\n\rsecret_secret\x18\x04 \x01(\tB\x02\x18\x01\x12\x1a\n\x12secret_service_url\x18\x05 \x01(\t\x12\x14\n\x08role_arn\x18\x06 \x01(\tB\x02\x18\x01\x12G\n\x0f\x61ws_credentials\x18\x07 \x01(\x0b\x32,.qwak.kube.deployment.captain.AwsCredentialsH\x00\x12G\n\x0fgcp_credentials\x18\x08 \x01(\x0b\x32,.qwak.kube.deployment.captain.GcpCredentialsH\x00\x12P\n\x14grouped_task_details\x18\t \x01(\x0b\x32\x30.qwak.kube.deployment.captain.GroupedTaskDetailsH\x01\x12\x16\n\x0e\x65nvironment_id\x18\n \x01(\tB\x1a\n\x18\x63loud_client_credentialsB\x0b\n\ttask_flow\"c\n\x12GroupedTaskDetails\x12\x17\n\x0f\x63oncurrentTasks\x18\x01 \x01(\x05\x12\x18\n\x10\x64\x65stination_path\x18\x02 \x01(\t\x12\x1a\n\x12\x64\x65stination_bucket\x18\x03 \x01(\t\"\xb4\x02\n)CleanStorageObjectFromCloudStorageRequest\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x15\n\robject_prefix\x18\x02 \x03(\t\x12\x1a\n\x12secret_service_url\x18\x03 \x01(\t\x12G\n\x0f\x61ws_credentials\x18\x04 \x01(\x0b\x32,.qwak.kube.deployment.captain.AwsCredentialsH\x00\x12G\n\x0fgcp_credentials\x18\x05 \x01(\x0b\x32,.qwak.kube.deployment.captain.GcpCredentialsH\x00\x12\x16\n\x0e\x65nvironment_id\x18\x06 \x01(\tB\x1a\n\x18\x63loud_client_credentials\"O\n\x0e\x41wsCredentials\x12\x10\n\x08role_arn\x18\x01 \x01(\t\x12\x14\n\x0ctoken_secret\x18\x02 \x01(\t\x12\x15\n\rsecret_secret\x18\x04 \x01(\t\"9\n\x0eGcpCredentials\x12\'\n\x1fservice_account_json_key_secret\x18\x01 \x01(\t\"\xa6\x01\n\x1dListInferenceJobFilesResponse\x12\x12\n\nfile_names\x18\x01 \x03(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x16\n\x0e\x66\x61ilure_reason\x18\x03 \x01(\t\x12H\n\x11list_file_details\x18\x04 \x03(\x0b\x32-.qwak.kube.deployment.captain.ListFileDetails\"W\n\x0fListFileDetails\x12\x15\n\ris_point_file\x18\x01 \x01(\x08\x12\x17\n\x0fpoint_file_path\x18\x02 \x01(\t\x12\x14\n\x0cobject_paths\x18\x03 \x03(\t\"\xf0\x01\n\"CreateInferenceTaskExecutorRequest\x12\x63\n\x1btask_executor_configuration\x18\x01 \x01(\x0b\x32>.qwak.kube.deployment.captain.TaskExecutorConfigurationMessage\x12\x65\n\x1cinference_task_configuration\x18\x02 \x01(\x0b\x32?.qwak.kube.deployment.captain.InferenceTaskConfigurationMessage\"\x89\x01\n\x1aPrepareInferenceJobRequest\x12k\n#inference_job_configuration_message\x18\x01 \x01(\x0b\x32>.qwak.kube.deployment.captain.InferenceJobConfigurationMessage\"F\n\x1bPrepareInferenceJobResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x16\n\x0e\x66\x61ilure_reason\x18\x02 \x01(\t\"\xcd\x04\n TaskExecutorConfigurationMessage\x12\x18\n\x10inference_job_id\x18\x01 \x01(\t\x12\x19\n\x11inference_task_id\x18\x02 \x01(\t\x12G\n\x10model_identifier\x18\x05 \x01(\x0b\x32-.qwak.kube.deployment.captain.ModelIdentifier\x12\x11\n\timage_url\x18\x06 \x01(\t\x12\x15\n\rbackoff_limit\x18\x07 \x01(\x05\x12\x0f\n\x03\x63pu\x18\x08 \x01(\x02\x42\x02\x18\x01\x12\x19\n\rmemory_amount\x18\t \x01(\x05\x42\x02\x18\x01\x12\x45\n\x0cmemory_units\x18\n \x01(\x0e\x32+.qwak.kube.deployment.captain.MemoryUnitApiB\x02\x18\x01\x12\x16\n\x0e\x65nvironment_id\x18\x0b \x01(\t\x12\x1b\n\x13\x63ustom_iam_role_arn\x18\x0c \x01(\t\x12\x41\n\x08job_size\x18\r \x01(\x0b\x32/.qwak.kube.deployment.captain.BatchJobResources\x12\x17\n\x0fpurchase_option\x18\x0e \x01(\t\x12\x19\n\x11image_pull_secret\x18\x0f \x01(\t\x12%\n\x1d\x63ustom_service_account_secret\x18\x10 \x01(\t\x12#\n\x1bjfrog_token_api_secret_name\x18\x11 \x01(\t\x12\x16\n\x0ejfrog_base_url\x18\x12 \x01(\t\"q\n InferenceJobConfigurationMessage\x12\x18\n\x10inference_job_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x02 \x01(\t\x12\x1b\n\x13\x63ustom_iam_role_arn\x18\x03 \x01(\t\"`\n\x0fModelIdentifier\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x02 \x01(\t\x12\x15\n\tbranch_id\x18\x03 \x01(\tB\x02\x18\x01\x12\x12\n\nmodel_uuid\x18\x04 \x01(\t\"\xa2\x01\n\x1dListFilesPreStepConfiguration\x12\x13\n\x0bsource_path\x18\x01 \x01(\t\x12\x1c\n\x14list_files_file_name\x18\x02 \x01(\t\x12\x1d\n\x15total_number_of_tasks\x18\x03 \x01(\x05\x12/\n\ntask_index\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\"\xf4\x04\n!InferenceTaskConfigurationMessage\x12\x15\n\rsource_bucket\x18\x01 \x01(\t\x12\x1a\n\x12\x64\x65stination_bucket\x18\x02 \x01(\t\x12\x10\n\x08\x66ilepath\x18\x03 \x01(\t\x12\x18\n\x10\x64\x65stination_path\x18\x04 \x01(\t\x12\x44\n\x0finput_file_type\x18\x05 \x01(\x0e\x32+.qwak.kube.deployment.captain.InputFileType\x12\x46\n\x10output_file_type\x18\x06 \x01(\x0e\x32,.qwak.kube.deployment.captain.OutputFileType\x12\x14\n\x0ctoken_secret\x18\x07 \x01(\t\x12\x15\n\rsecret_secret\x18\x08 \x01(\t\x12\x43\n\nparameters\x18\t \x03(\x0b\x32/.qwak.kube.deployment.captain.BatchJobParameter\x12\x43\n\x0e\x63loud_provider\x18\n \x01(\x0e\x32+.qwak.kube.deployment.captain.CloudProvider\x12\'\n\x1fservice_account_json_key_secret\x18\x0b \x01(\t\x12\x1a\n\x12is_point_file_path\x18\x0c \x01(\x08\x12\x66\n!list_files_pre_step_configuration\x18\r \x01(\x0b\x32;.qwak.kube.deployment.captain.ListFilesPreStepConfiguration\"/\n\x11\x42\x61tchJobParameter\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"?\n#CleanInferenceTasksExecutorsRequest\x12\x18\n\x10inference_job_id\x18\x01 \x01(\t\"O\n$CleanInferenceTasksExecutorsResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x16\n\x0e\x66\x61ilure_reason\x18\x02 \x01(\t\"X\n!CleanInferenceTaskExecutorRequest\x12\x18\n\x10inference_job_id\x18\x01 \x01(\t\x12\x19\n\x11inference_task_id\x18\x02 \x01(\t\"M\n\"CleanInferenceTaskExecutorResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x16\n\x0e\x66\x61ilure_reason\x18\x02 \x01(\t\"N\n#CreateInferenceTaskExecutorResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x16\n\x0e\x66\x61ilure_reason\x18\x02 \x01(\t\"\xf7\x02\n\x1eStartInferenceJobWarmupRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x10\n\x08\x62uild_id\x18\x03 \x01(\t\x12\x11\n\timage_url\x18\x04 \x01(\t\x12\x0f\n\x03\x63pu\x18\x05 \x01(\x02\x42\x02\x18\x01\x12\x19\n\rmemory_amount\x18\x06 \x01(\x05\x42\x02\x18\x01\x12\x45\n\x0cmemory_units\x18\x07 \x01(\x0e\x32+.qwak.kube.deployment.captain.MemoryUnitApiB\x02\x18\x01\x12\x11\n\texecutors\x18\x08 \x01(\x05\x12\x0f\n\x07timeout\x18\t \x01(\x05\x12\x41\n\x08job_size\x18\n \x01(\x0b\x32/.qwak.kube.deployment.captain.BatchJobResources\x12\x12\n\nmodel_uuid\x18\x0b \x01(\t\x12\x19\n\x11image_pull_secret\x18\x0c \x01(\t\"!\n\x1fStartInferenceJobWarmupResponse\"p\n\x1f\x43\x61ncelInferenceJobWarmupRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x10\n\x08\x62uild_id\x18\x03 \x01(\t\x12\x12\n\nmodel_uuid\x18\x04 \x01(\t\"\"\n CancelInferenceJobWarmupResponse\"\xd5\x01\n\x11\x42\x61tchJobResources\x12\x16\n\x0enumber_of_pods\x18\x01 \x01(\x05\x12\x0b\n\x03\x63pu\x18\x02 \x01(\x02\x12\x15\n\rmemory_amount\x18\x03 \x01(\x05\x12\x41\n\x0cmemory_units\x18\x04 \x01(\x0e\x32+.qwak.kube.deployment.captain.MemoryUnitApi\x12\x41\n\rgpu_resources\x18\x05 \x01(\x0b\x32*.qwak.kube.deployment.captain.GpuResources\"[\n\x0cGpuResources\x12\x37\n\x08gpu_type\x18\x01 \x01(\x0e\x32%.qwak.kube.deployment.captain.GpuType\x12\x12\n\ngpu_amount\x18\x02 \x01(\x05*:\n\rMemoryUnitApi\x12\x17\n\x13UNKNOWN_MEMORY_UNIT\x10\x00\x12\x07\n\x03MIB\x10\x01\x12\x07\n\x03GIB\x10\x02*\x81\x01\n\rInputFileType\x12\x1d\n\x19UNDEFINED_INPUT_FILE_TYPE\x10\x00\x12\x17\n\x13\x43SV_INPUT_FILE_TYPE\x10\x01\x12\x1b\n\x17\x46\x45\x41THER_INPUT_FILE_TYPE\x10\x02\x12\x1b\n\x17PARQUET_INPUT_FILE_TYPE\x10\x03*\x86\x01\n\x0eOutputFileType\x12\x1e\n\x1aUNDEFINED_OUTPUT_FILE_TYPE\x10\x00\x12\x18\n\x14\x43SV_OUTPUT_FILE_TYPE\x10\x01\x12\x1c\n\x18\x46\x45\x41THER_OUTPUT_FILE_TYPE\x10\x02\x12\x1c\n\x18PARQUET_OUTPUT_FILE_TYPE\x10\x03*\x90\x02\n\x07GpuType\x12\x0f\n\x0bINVALID_GPU\x10\x00\x12\x0e\n\nNVIDIA_K80\x10\x01\x12\x0f\n\x0bNVIDIA_V100\x10\x02\x12\x0f\n\x0bNVIDIA_A100\x10\x03\x12\r\n\tNVIDIA_T4\x10\x04\x12\x0f\n\x0bNVIDIA_A10G\x10\x05\x12\r\n\tNVIDIA_L4\x10\x06\x12\x14\n\x10NVIDIA_T4_1_4_15\x10\x07\x12\x14\n\x10NVIDIA_T4_1_8_30\x10\x08\x12\x15\n\x11NVIDIA_T4_1_16_60\x10\t\x12\x1e\n\x1aNVIDIA_A100_80GB_8_96_1360\x10\n\x12\x16\n\x12NVIDIA_V100_1_8_52\x10\x0b\x12\x18\n\x14NVIDIA_V100_4_32_208\x10\x0c*=\n\rCloudProvider\x12\x1a\n\x16UNKNOWN_CLOUD_PROVIDER\x10\x00\x12\x07\n\x03\x41WS\x10\x01\x12\x07\n\x03GCP\x10\x02\x42+\n\'com.qwak.ai.kube.deployment.captain.apiP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.kube_deployment_captain.batch_job_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\'com.qwak.ai.kube.deployment.captain.apiP\001'
  _LISTINFERENCEJOBFILESREQUEST.fields_by_name['token_secret']._options = None
  _LISTINFERENCEJOBFILESREQUEST.fields_by_name['token_secret']._serialized_options = b'\030\001'
  _LISTINFERENCEJOBFILESREQUEST.fields_by_name['secret_secret']._options = None
  _LISTINFERENCEJOBFILESREQUEST.fields_by_name['secret_secret']._serialized_options = b'\030\001'
  _LISTINFERENCEJOBFILESREQUEST.fields_by_name['role_arn']._options = None
  _LISTINFERENCEJOBFILESREQUEST.fields_by_name['role_arn']._serialized_options = b'\030\001'
  _TASKEXECUTORCONFIGURATIONMESSAGE.fields_by_name['cpu']._options = None
  _TASKEXECUTORCONFIGURATIONMESSAGE.fields_by_name['cpu']._serialized_options = b'\030\001'
  _TASKEXECUTORCONFIGURATIONMESSAGE.fields_by_name['memory_amount']._options = None
  _TASKEXECUTORCONFIGURATIONMESSAGE.fields_by_name['memory_amount']._serialized_options = b'\030\001'
  _TASKEXECUTORCONFIGURATIONMESSAGE.fields_by_name['memory_units']._options = None
  _TASKEXECUTORCONFIGURATIONMESSAGE.fields_by_name['memory_units']._serialized_options = b'\030\001'
  _MODELIDENTIFIER.fields_by_name['branch_id']._options = None
  _MODELIDENTIFIER.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _STARTINFERENCEJOBWARMUPREQUEST.fields_by_name['branch_id']._options = None
  _STARTINFERENCEJOBWARMUPREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _STARTINFERENCEJOBWARMUPREQUEST.fields_by_name['cpu']._options = None
  _STARTINFERENCEJOBWARMUPREQUEST.fields_by_name['cpu']._serialized_options = b'\030\001'
  _STARTINFERENCEJOBWARMUPREQUEST.fields_by_name['memory_amount']._options = None
  _STARTINFERENCEJOBWARMUPREQUEST.fields_by_name['memory_amount']._serialized_options = b'\030\001'
  _STARTINFERENCEJOBWARMUPREQUEST.fields_by_name['memory_units']._options = None
  _STARTINFERENCEJOBWARMUPREQUEST.fields_by_name['memory_units']._serialized_options = b'\030\001'
  _CANCELINFERENCEJOBWARMUPREQUEST.fields_by_name['branch_id']._options = None
  _CANCELINFERENCEJOBWARMUPREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _globals['_MEMORYUNITAPI']._serialized_start=4761
  _globals['_MEMORYUNITAPI']._serialized_end=4819
  _globals['_INPUTFILETYPE']._serialized_start=4822
  _globals['_INPUTFILETYPE']._serialized_end=4951
  _globals['_OUTPUTFILETYPE']._serialized_start=4954
  _globals['_OUTPUTFILETYPE']._serialized_end=5088
  _globals['_GPUTYPE']._serialized_start=5091
  _globals['_GPUTYPE']._serialized_end=5363
  _globals['_CLOUDPROVIDER']._serialized_start=5365
  _globals['_CLOUDPROVIDER']._serialized_end=5426
  _globals['_LISTINFERENCEJOBFILESREQUEST']._serialized_start=111
  _globals['_LISTINFERENCEJOBFILESREQUEST']._serialized_end=577
  _globals['_GROUPEDTASKDETAILS']._serialized_start=579
  _globals['_GROUPEDTASKDETAILS']._serialized_end=678
  _globals['_CLEANSTORAGEOBJECTFROMCLOUDSTORAGEREQUEST']._serialized_start=681
  _globals['_CLEANSTORAGEOBJECTFROMCLOUDSTORAGEREQUEST']._serialized_end=989
  _globals['_AWSCREDENTIALS']._serialized_start=991
  _globals['_AWSCREDENTIALS']._serialized_end=1070
  _globals['_GCPCREDENTIALS']._serialized_start=1072
  _globals['_GCPCREDENTIALS']._serialized_end=1129
  _globals['_LISTINFERENCEJOBFILESRESPONSE']._serialized_start=1132
  _globals['_LISTINFERENCEJOBFILESRESPONSE']._serialized_end=1298
  _globals['_LISTFILEDETAILS']._serialized_start=1300
  _globals['_LISTFILEDETAILS']._serialized_end=1387
  _globals['_CREATEINFERENCETASKEXECUTORREQUEST']._serialized_start=1390
  _globals['_CREATEINFERENCETASKEXECUTORREQUEST']._serialized_end=1630
  _globals['_PREPAREINFERENCEJOBREQUEST']._serialized_start=1633
  _globals['_PREPAREINFERENCEJOBREQUEST']._serialized_end=1770
  _globals['_PREPAREINFERENCEJOBRESPONSE']._serialized_start=1772
  _globals['_PREPAREINFERENCEJOBRESPONSE']._serialized_end=1842
  _globals['_TASKEXECUTORCONFIGURATIONMESSAGE']._serialized_start=1845
  _globals['_TASKEXECUTORCONFIGURATIONMESSAGE']._serialized_end=2434
  _globals['_INFERENCEJOBCONFIGURATIONMESSAGE']._serialized_start=2436
  _globals['_INFERENCEJOBCONFIGURATIONMESSAGE']._serialized_end=2549
  _globals['_MODELIDENTIFIER']._serialized_start=2551
  _globals['_MODELIDENTIFIER']._serialized_end=2647
  _globals['_LISTFILESPRESTEPCONFIGURATION']._serialized_start=2650
  _globals['_LISTFILESPRESTEPCONFIGURATION']._serialized_end=2812
  _globals['_INFERENCETASKCONFIGURATIONMESSAGE']._serialized_start=2815
  _globals['_INFERENCETASKCONFIGURATIONMESSAGE']._serialized_end=3443
  _globals['_BATCHJOBPARAMETER']._serialized_start=3445
  _globals['_BATCHJOBPARAMETER']._serialized_end=3492
  _globals['_CLEANINFERENCETASKSEXECUTORSREQUEST']._serialized_start=3494
  _globals['_CLEANINFERENCETASKSEXECUTORSREQUEST']._serialized_end=3557
  _globals['_CLEANINFERENCETASKSEXECUTORSRESPONSE']._serialized_start=3559
  _globals['_CLEANINFERENCETASKSEXECUTORSRESPONSE']._serialized_end=3638
  _globals['_CLEANINFERENCETASKEXECUTORREQUEST']._serialized_start=3640
  _globals['_CLEANINFERENCETASKEXECUTORREQUEST']._serialized_end=3728
  _globals['_CLEANINFERENCETASKEXECUTORRESPONSE']._serialized_start=3730
  _globals['_CLEANINFERENCETASKEXECUTORRESPONSE']._serialized_end=3807
  _globals['_CREATEINFERENCETASKEXECUTORRESPONSE']._serialized_start=3809
  _globals['_CREATEINFERENCETASKEXECUTORRESPONSE']._serialized_end=3887
  _globals['_STARTINFERENCEJOBWARMUPREQUEST']._serialized_start=3890
  _globals['_STARTINFERENCEJOBWARMUPREQUEST']._serialized_end=4265
  _globals['_STARTINFERENCEJOBWARMUPRESPONSE']._serialized_start=4267
  _globals['_STARTINFERENCEJOBWARMUPRESPONSE']._serialized_end=4300
  _globals['_CANCELINFERENCEJOBWARMUPREQUEST']._serialized_start=4302
  _globals['_CANCELINFERENCEJOBWARMUPREQUEST']._serialized_end=4414
  _globals['_CANCELINFERENCEJOBWARMUPRESPONSE']._serialized_start=4416
  _globals['_CANCELINFERENCEJOBWARMUPRESPONSE']._serialized_end=4450
  _globals['_BATCHJOBRESOURCES']._serialized_start=4453
  _globals['_BATCHJOBRESOURCES']._serialized_end=4666
  _globals['_GPURESOURCES']._serialized_start=4668
  _globals['_GPURESOURCES']._serialized_end=4759
# @@protoc_insertion_point(module_scope)
