"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.execution.v1.backfill_pb2
import qwak.execution.v1.batch_pb2
import qwak.execution.v1.execution_pb2
import qwak.execution.v1.streaming_aggregation_pb2
import qwak.execution.v1.streaming_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ListLastExecutionsForEnvironmentRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListLastExecutionsForEnvironmentRequest = ListLastExecutionsForEnvironmentRequest

class ListLastExecutionsForEnvironmentResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class FeaturesetIdToLastExecutionEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> qwak.execution.v1.execution_pb2.ExecutionEntry: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: qwak.execution.v1.execution_pb2.ExecutionEntry | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    FEATURESET_ID_TO_LAST_EXECUTION_FIELD_NUMBER: builtins.int
    @property
    def featureset_id_to_last_execution(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, qwak.execution.v1.execution_pb2.ExecutionEntry]:
        """A map between the Featureset IDs of the environment and their respective last executions."""
    def __init__(
        self,
        *,
        featureset_id_to_last_execution: collections.abc.Mapping[builtins.str, qwak.execution.v1.execution_pb2.ExecutionEntry] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_id_to_last_execution", b"featureset_id_to_last_execution"]) -> None: ...

global___ListLastExecutionsForEnvironmentResponse = ListLastExecutionsForEnvironmentResponse

class TriggerBackfillRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKFILL_SPEC_FIELD_NUMBER: builtins.int
    @property
    def backfill_spec(self) -> qwak.execution.v1.backfill_pb2.BackfillSpec: ...
    def __init__(
        self,
        *,
        backfill_spec: qwak.execution.v1.backfill_pb2.BackfillSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["backfill_spec", b"backfill_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backfill_spec", b"backfill_spec"]) -> None: ...

global___TriggerBackfillRequest = TriggerBackfillRequest

class TriggerBackfillResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ID_FIELD_NUMBER: builtins.int
    execution_id: builtins.str
    def __init__(
        self,
        *,
        execution_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_id", b"execution_id"]) -> None: ...

global___TriggerBackfillResponse = TriggerBackfillResponse

class GetExecutionStatusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ID_FIELD_NUMBER: builtins.int
    execution_id: builtins.str
    def __init__(
        self,
        *,
        execution_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_id", b"execution_id"]) -> None: ...

global___GetExecutionStatusRequest = GetExecutionStatusRequest

class GetExecutionStatusResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_STATUS_FIELD_NUMBER: builtins.int
    execution_status: qwak.execution.v1.execution_pb2.ExecutionStatus.ValueType
    def __init__(
        self,
        *,
        execution_status: qwak.execution.v1.execution_pb2.ExecutionStatus.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_status", b"execution_status"]) -> None: ...

global___GetExecutionStatusResponse = GetExecutionStatusResponse

class GetExecutionEntryRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ID_FIELD_NUMBER: builtins.int
    execution_id: builtins.str
    def __init__(
        self,
        *,
        execution_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_id", b"execution_id"]) -> None: ...

global___GetExecutionEntryRequest = GetExecutionEntryRequest

class GetExecutionEntryResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ENTRY_FIELD_NUMBER: builtins.int
    @property
    def execution_entry(self) -> qwak.execution.v1.execution_pb2.ExecutionEntry: ...
    def __init__(
        self,
        *,
        execution_entry: qwak.execution.v1.execution_pb2.ExecutionEntry | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["execution_entry", b"execution_entry"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_entry", b"execution_entry"]) -> None: ...

global___GetExecutionEntryResponse = GetExecutionEntryResponse

class TriggerBatchFeaturesetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BATCH_INGESTION_FIELD_NUMBER: builtins.int
    @property
    def batch_ingestion(self) -> qwak.execution.v1.batch_pb2.BatchIngestion: ...
    def __init__(
        self,
        *,
        batch_ingestion: qwak.execution.v1.batch_pb2.BatchIngestion | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["batch_ingestion", b"batch_ingestion"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["batch_ingestion", b"batch_ingestion"]) -> None: ...

global___TriggerBatchFeaturesetRequest = TriggerBatchFeaturesetRequest

class TriggerBatchFeaturesetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ID_FIELD_NUMBER: builtins.int
    execution_id: builtins.str
    def __init__(
        self,
        *,
        execution_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_id", b"execution_id"]) -> None: ...

global___TriggerBatchFeaturesetResponse = TriggerBatchFeaturesetResponse

class GetRunningExecutionEntriesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_ID_FIELD_NUMBER: builtins.int
    featureset_id: builtins.str
    def __init__(
        self,
        *,
        featureset_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_id", b"featureset_id"]) -> None: ...

global___GetRunningExecutionEntriesRequest = GetRunningExecutionEntriesRequest

class GetRunningExecutionEntriesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ENTRIES_FIELD_NUMBER: builtins.int
    @property
    def execution_entries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.execution.v1.execution_pb2.ExecutionEntry]: ...
    def __init__(
        self,
        *,
        execution_entries: collections.abc.Iterable[qwak.execution.v1.execution_pb2.ExecutionEntry] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_entries", b"execution_entries"]) -> None: ...

global___GetRunningExecutionEntriesResponse = GetRunningExecutionEntriesResponse

class TriggerFeaturesetDeletionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_ID_FIELD_NUMBER: builtins.int
    featureset_id: builtins.str
    def __init__(
        self,
        *,
        featureset_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_id", b"featureset_id"]) -> None: ...

global___TriggerFeaturesetDeletionRequest = TriggerFeaturesetDeletionRequest

class TriggerFeaturesetDeletionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ID_FIELD_NUMBER: builtins.int
    execution_id: builtins.str
    def __init__(
        self,
        *,
        execution_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_id", b"execution_id"]) -> None: ...

global___TriggerFeaturesetDeletionResponse = TriggerFeaturesetDeletionResponse

class InitPaginationByFeaturesetIdRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_ID_FIELD_NUMBER: builtins.int
    featureset_id: builtins.str
    """the featureset id for which to start a pagination"""
    def __init__(
        self,
        *,
        featureset_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_id", b"featureset_id"]) -> None: ...

global___InitPaginationByFeaturesetIdRequest = InitPaginationByFeaturesetIdRequest

class InitPaginationByFeaturesetIdResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RECORD_COUNT_FIELD_NUMBER: builtins.int
    MAX_EXECUTION_INDEX_FIELD_NUMBER: builtins.int
    record_count: builtins.int
    """Number of executions found for this Featureset at the time of querying
    this is used mainly by the client to plan things like number of pages etc.
    """
    max_execution_index: builtins.int
    """the current highest execution index for this FS. this is the anchor
    to use on subsequent requests if the caller wants to achieve
    a view of a static list
    """
    def __init__(
        self,
        *,
        record_count: builtins.int = ...,
        max_execution_index: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_execution_index", b"max_execution_index", "record_count", b"record_count"]) -> None: ...

global___InitPaginationByFeaturesetIdResponse = InitPaginationByFeaturesetIdResponse

class ListExecutionsByFeaturesetIdRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_NUMBER_FIELD_NUMBER: builtins.int
    MAX_EXECUTION_INDEX_FIELD_NUMBER: builtins.int
    featureset_id: builtins.str
    """featureset id"""
    page_size: builtins.int
    """The page size to use for the response - the number of results in the response
    is the minimum of the page_size and number of matching rows.
    - a negative value means all results will be returned (in that case page_number is ignored)
    """
    page_number: builtins.int
    """The page number to use"""
    max_execution_index: builtins.int
    """The max execution index to use as anchor - this is the value returned from InitPaginationByFeaturesetId"""
    def __init__(
        self,
        *,
        featureset_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_number: builtins.int = ...,
        max_execution_index: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_id", b"featureset_id", "max_execution_index", b"max_execution_index", "page_number", b"page_number", "page_size", b"page_size"]) -> None: ...

global___ListExecutionsByFeaturesetIdRequest = ListExecutionsByFeaturesetIdRequest

class ListExecutionsByFeaturesetIdResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ENTRIES_FIELD_NUMBER: builtins.int
    @property
    def execution_entries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.execution.v1.execution_pb2.ExecutionEntry]: ...
    def __init__(
        self,
        *,
        execution_entries: collections.abc.Iterable[qwak.execution.v1.execution_pb2.ExecutionEntry] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_entries", b"execution_entries"]) -> None: ...

global___ListExecutionsByFeaturesetIdResponse = ListExecutionsByFeaturesetIdResponse

class TriggerOnlineStreamingIngestionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ONLINE_STREAMING_INGESTION_FIELD_NUMBER: builtins.int
    @property
    def online_streaming_ingestion(self) -> qwak.execution.v1.streaming_pb2.OnlineStreamingIngestion: ...
    def __init__(
        self,
        *,
        online_streaming_ingestion: qwak.execution.v1.streaming_pb2.OnlineStreamingIngestion | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["online_streaming_ingestion", b"online_streaming_ingestion"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["online_streaming_ingestion", b"online_streaming_ingestion"]) -> None: ...

global___TriggerOnlineStreamingIngestionRequest = TriggerOnlineStreamingIngestionRequest

class TriggerOnlineStreamingIngestionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ID_FIELD_NUMBER: builtins.int
    execution_id: builtins.str
    def __init__(
        self,
        *,
        execution_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_id", b"execution_id"]) -> None: ...

global___TriggerOnlineStreamingIngestionResponse = TriggerOnlineStreamingIngestionResponse

class TriggerOfflineStreamingIngestionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OFFLINE_STREAMING_INGESTION_FIELD_NUMBER: builtins.int
    @property
    def offline_streaming_ingestion(self) -> qwak.execution.v1.streaming_pb2.OfflineStreamingIngestion: ...
    def __init__(
        self,
        *,
        offline_streaming_ingestion: qwak.execution.v1.streaming_pb2.OfflineStreamingIngestion | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["offline_streaming_ingestion", b"offline_streaming_ingestion"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["offline_streaming_ingestion", b"offline_streaming_ingestion"]) -> None: ...

global___TriggerOfflineStreamingIngestionRequest = TriggerOfflineStreamingIngestionRequest

class TriggerOfflineStreamingIngestionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ID_FIELD_NUMBER: builtins.int
    execution_id: builtins.str
    def __init__(
        self,
        *,
        execution_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_id", b"execution_id"]) -> None: ...

global___TriggerOfflineStreamingIngestionResponse = TriggerOfflineStreamingIngestionResponse

class TriggerRowLevelStreamingAggregationIngestionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROW_LEVEL_INGESTION_FIELD_NUMBER: builtins.int
    @property
    def row_level_ingestion(self) -> qwak.execution.v1.streaming_aggregation_pb2.RowLevelStreamingAggregationIngestion: ...
    def __init__(
        self,
        *,
        row_level_ingestion: qwak.execution.v1.streaming_aggregation_pb2.RowLevelStreamingAggregationIngestion | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["row_level_ingestion", b"row_level_ingestion"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["row_level_ingestion", b"row_level_ingestion"]) -> None: ...

global___TriggerRowLevelStreamingAggregationIngestionRequest = TriggerRowLevelStreamingAggregationIngestionRequest

class TriggerRowLevelStreamingAggregationIngestionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ID_FIELD_NUMBER: builtins.int
    execution_id: builtins.str
    def __init__(
        self,
        *,
        execution_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_id", b"execution_id"]) -> None: ...

global___TriggerRowLevelStreamingAggregationIngestionResponse = TriggerRowLevelStreamingAggregationIngestionResponse

class TriggerCompactionStreamingAggregationIngestionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPACTION_INGESTION_FIELD_NUMBER: builtins.int
    @property
    def compaction_ingestion(self) -> qwak.execution.v1.streaming_aggregation_pb2.CompactionStreamingAggregationIngestion: ...
    def __init__(
        self,
        *,
        compaction_ingestion: qwak.execution.v1.streaming_aggregation_pb2.CompactionStreamingAggregationIngestion | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compaction_ingestion", b"compaction_ingestion"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compaction_ingestion", b"compaction_ingestion"]) -> None: ...

global___TriggerCompactionStreamingAggregationIngestionRequest = TriggerCompactionStreamingAggregationIngestionRequest

class TriggerCompactionStreamingAggregationIngestionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ID_FIELD_NUMBER: builtins.int
    execution_id: builtins.str
    def __init__(
        self,
        *,
        execution_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_id", b"execution_id"]) -> None: ...

global___TriggerCompactionStreamingAggregationIngestionResponse = TriggerCompactionStreamingAggregationIngestionResponse

class TriggerStreamingAggregationBackfillRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKFILL_FIELD_NUMBER: builtins.int
    @property
    def backfill(self) -> qwak.execution.v1.streaming_aggregation_pb2.StreamingAggregationBackfillIngestion: ...
    def __init__(
        self,
        *,
        backfill: qwak.execution.v1.streaming_aggregation_pb2.StreamingAggregationBackfillIngestion | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["backfill", b"backfill"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backfill", b"backfill"]) -> None: ...

global___TriggerStreamingAggregationBackfillRequest = TriggerStreamingAggregationBackfillRequest

class TriggerStreamingAggregationBackfillResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ID_FIELD_NUMBER: builtins.int
    execution_id: builtins.str
    def __init__(
        self,
        *,
        execution_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_id", b"execution_id"]) -> None: ...

global___TriggerStreamingAggregationBackfillResponse = TriggerStreamingAggregationBackfillResponse
