# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/serving/serving.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(qwak/feature_store/serving/serving.proto\x12%com.qwak.ai.feature.store.serving.api\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa8\x02\n\x1eRequestedEntitiesMatrixRequest\x12U\n\x14\x65ntities_to_features\x18\x01 \x03(\x0b\x32\x37.com.qwak.ai.feature.store.serving.api.EntityToFeatures\x12\\\n\x14\x65ntity_values_matrix\x18\x02 \x01(\x0b\x32>.com.qwak.ai.feature.store.serving.api.RequestedEntitiesMatrix\x12Q\n\x11request_meta_data\x18\x03 \x01(\x0b\x32\x36.com.qwak.ai.feature.store.serving.api.RequestMetaData\"R\n\x0fRequestMetaData\x12\x12\n\nmodel_name\x18\x01 \x01(\t\x12\x10\n\x08num_keys\x18\x02 \x01(\x05\x12\x19\n\x11\x66\x65\x61ture_set_names\x18\x03 \x03(\t\"\xa5\x01\n\x17RequestedEntitiesMatrix\x12\x45\n\x06header\x18\x01 \x01(\x0b\x32\x35.com.qwak.ai.feature.store.serving.api.EntitiesHeader\x12\x43\n\x04rows\x18\x02 \x03(\x0b\x32\x35.com.qwak.ai.feature.store.serving.api.EntityValueRow\"&\n\x0e\x45ntitiesHeader\x12\x14\n\x0c\x65ntity_names\x18\x01 \x03(\t\"6\n\x0e\x45ntityValueRow\x12\r\n\x05index\x18\x01 \x01(\x05\x12\x15\n\rentity_values\x18\x02 \x03(\t\"i\n\x10\x45ntityToFeatures\x12@\n\x08\x66\x65\x61tures\x18\x01 \x03(\x0b\x32..com.qwak.ai.feature.store.serving.api.Feature\x12\x13\n\x0b\x65ntity_name\x18\x02 \x01(\t\"\xd3\x01\n\x14\x46\x65\x61tureValuesRequest\x12@\n\x08\x66\x65\x61tures\x18\x01 \x03(\x0b\x32..com.qwak.ai.feature.store.serving.api.Feature\x12R\n\x06\x65ntity\x18\x02 \x01(\x0b\x32\x42.com.qwak.ai.feature.store.serving.api.FeatureValuesRequest.Entity\x1a%\n\x06\x45ntity\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xa2\x04\n\x07\x46\x65\x61ture\x12L\n\rbatch_feature\x18\x01 \x01(\x0b\x32\x33.com.qwak.ai.feature.store.serving.api.BatchFeatureH\x00\x12X\n\x12on_the_fly_feature\x18\x02 \x01(\x0b\x32\x36.com.qwak.ai.feature.store.serving.api.OnTheFlyFeatureB\x02\x18\x01H\x00\x12T\n\x11streaming_feature\x18\x03 \x01(\x0b\x32\x37.com.qwak.ai.feature.store.serving.api.StreamingFeatureH\x00\x12\x63\n\x15streaming_aggregation\x18\x04 \x01(\x0b\x32\x42.com.qwak.ai.feature.store.serving.api.StreamingAggregationFeatureH\x00\x12Q\n\x10\x62\x61tch_v1_feature\x18\x05 \x01(\x0b\x32\x35.com.qwak.ai.feature.store.serving.api.BatchV1FeatureH\x00\x12Y\n\x14streaming_v1_feature\x18\x06 \x01(\x0b\x32\x39.com.qwak.ai.feature.store.serving.api.StreamingV1FeatureH\x00\x42\x06\n\x04type\"\x1c\n\x0c\x42\x61tchFeature\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x1e\n\x0e\x42\x61tchV1Feature\x12\x0c\n\x04name\x18\x01 \x01(\t\" \n\x10StreamingFeature\x12\x0c\n\x04name\x18\x01 \x01(\t\"\"\n\x12StreamingV1Feature\x12\x0c\n\x04name\x18\x01 \x01(\t\"+\n\x1bStreamingAggregationFeature\x12\x0c\n\x04name\x18\x01 \x01(\t\"u\n\x0fOnTheFlyFeature\x12\x10\n\x04name\x18\x01 \x01(\tB\x02\x18\x01\x12P\n\x0fon_the_fly_data\x18\x02 \x01(\x0b\x32\x33.com.qwak.ai.feature.store.serving.api.OnTheFlyDataB\x02\x18\x01\"O\n\x1aMultiFeatureValuesResponse\x12\x19\n\x11pandas_df_as_json\x18\x01 \x01(\t\x12\x16\n\x0e\x66\x65\x61ture_values\x18\x02 \x01(\t\"\xf4\x02\n\x15\x46\x65\x61tureValuesResponse\x12\x61\n\x0e\x66\x65\x61ture_values\x18\x01 \x03(\x0b\x32I.com.qwak.ai.feature.store.serving.api.FeatureValuesResponse.FeatureValue\x1a\xf7\x01\n\x0c\x46\x65\x61tureValue\x12\x14\n\x0c\x66\x65\x61ture_name\x18\x01 \x01(\t\x12\x43\n\rfeature_value\x18\x02 \x01(\x0b\x32,.com.qwak.ai.feature.store.serving.api.Value\x12\x65\n\x06status\x18\x03 \x01(\x0e\x32U.com.qwak.ai.feature.store.serving.api.FeatureValuesResponse.FeatureValue.ValueStatus\"%\n\x0bValueStatus\x12\x0b\n\x07INVALID\x10\x00\x12\t\n\x05VALID\x10\x01\"J\n\x0cOnTheFlyData\x12\x17\n\tuser_data\x18\x01 \x01(\tB\x02\x18\x01H\x00\x12\x19\n\x0bschema_data\x18\x02 \x01(\tB\x02\x18\x01H\x00\x42\x06\n\x04\x64\x61ta\"\x9a\x02\n\x05Value\x12\x13\n\tbytes_val\x18\x01 \x01(\x0cH\x00\x12\x14\n\nstring_val\x18\x02 \x01(\tH\x00\x12\x13\n\tint32_val\x18\x03 \x01(\x05H\x00\x12\x13\n\tint64_val\x18\x04 \x01(\x03H\x00\x12\x14\n\ndouble_val\x18\x05 \x01(\x01H\x00\x12\x13\n\tfloat_val\x18\x06 \x01(\x02H\x00\x12\x12\n\x08\x62ool_val\x18\x07 \x01(\x08H\x00\x12\x33\n\rtimestamp_val\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x12\x41\n\tarray_val\x18\t \x01(\x0b\x32,.com.qwak.ai.feature.store.serving.api.ArrayH\x00\x42\x05\n\x03val\"H\n\x05\x41rray\x12?\n\tarray_val\x18\x01 \x03(\x0b\x32,.com.qwak.ai.feature.store.serving.api.Value2\xba\x02\n\x0eServingService\x12\x88\x01\n\x0bGetFeatures\x12;.com.qwak.ai.feature.store.serving.api.FeatureValuesRequest\x1a<.com.qwak.ai.feature.store.serving.api.FeatureValuesResponse\x12\x9c\x01\n\x10GetMultiFeatures\x12\x45.com.qwak.ai.feature.store.serving.api.RequestedEntitiesMatrixRequest\x1a\x41.com.qwak.ai.feature.store.serving.api.MultiFeatureValuesResponseB\'\n%com.qwak.ai.feature.store.serving.apib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.feature_store.serving.serving_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.feature.store.serving.api'
  _FEATURE.fields_by_name['on_the_fly_feature']._options = None
  _FEATURE.fields_by_name['on_the_fly_feature']._serialized_options = b'\030\001'
  _ONTHEFLYFEATURE.fields_by_name['name']._options = None
  _ONTHEFLYFEATURE.fields_by_name['name']._serialized_options = b'\030\001'
  _ONTHEFLYFEATURE.fields_by_name['on_the_fly_data']._options = None
  _ONTHEFLYFEATURE.fields_by_name['on_the_fly_data']._serialized_options = b'\030\001'
  _ONTHEFLYDATA.fields_by_name['user_data']._options = None
  _ONTHEFLYDATA.fields_by_name['user_data']._serialized_options = b'\030\001'
  _ONTHEFLYDATA.fields_by_name['schema_data']._options = None
  _ONTHEFLYDATA.fields_by_name['schema_data']._serialized_options = b'\030\001'
  _globals['_REQUESTEDENTITIESMATRIXREQUEST']._serialized_start=117
  _globals['_REQUESTEDENTITIESMATRIXREQUEST']._serialized_end=413
  _globals['_REQUESTMETADATA']._serialized_start=415
  _globals['_REQUESTMETADATA']._serialized_end=497
  _globals['_REQUESTEDENTITIESMATRIX']._serialized_start=500
  _globals['_REQUESTEDENTITIESMATRIX']._serialized_end=665
  _globals['_ENTITIESHEADER']._serialized_start=667
  _globals['_ENTITIESHEADER']._serialized_end=705
  _globals['_ENTITYVALUEROW']._serialized_start=707
  _globals['_ENTITYVALUEROW']._serialized_end=761
  _globals['_ENTITYTOFEATURES']._serialized_start=763
  _globals['_ENTITYTOFEATURES']._serialized_end=868
  _globals['_FEATUREVALUESREQUEST']._serialized_start=871
  _globals['_FEATUREVALUESREQUEST']._serialized_end=1082
  _globals['_FEATUREVALUESREQUEST_ENTITY']._serialized_start=1045
  _globals['_FEATUREVALUESREQUEST_ENTITY']._serialized_end=1082
  _globals['_FEATURE']._serialized_start=1085
  _globals['_FEATURE']._serialized_end=1631
  _globals['_BATCHFEATURE']._serialized_start=1633
  _globals['_BATCHFEATURE']._serialized_end=1661
  _globals['_BATCHV1FEATURE']._serialized_start=1663
  _globals['_BATCHV1FEATURE']._serialized_end=1693
  _globals['_STREAMINGFEATURE']._serialized_start=1695
  _globals['_STREAMINGFEATURE']._serialized_end=1727
  _globals['_STREAMINGV1FEATURE']._serialized_start=1729
  _globals['_STREAMINGV1FEATURE']._serialized_end=1763
  _globals['_STREAMINGAGGREGATIONFEATURE']._serialized_start=1765
  _globals['_STREAMINGAGGREGATIONFEATURE']._serialized_end=1808
  _globals['_ONTHEFLYFEATURE']._serialized_start=1810
  _globals['_ONTHEFLYFEATURE']._serialized_end=1927
  _globals['_MULTIFEATUREVALUESRESPONSE']._serialized_start=1929
  _globals['_MULTIFEATUREVALUESRESPONSE']._serialized_end=2008
  _globals['_FEATUREVALUESRESPONSE']._serialized_start=2011
  _globals['_FEATUREVALUESRESPONSE']._serialized_end=2383
  _globals['_FEATUREVALUESRESPONSE_FEATUREVALUE']._serialized_start=2136
  _globals['_FEATUREVALUESRESPONSE_FEATUREVALUE']._serialized_end=2383
  _globals['_FEATUREVALUESRESPONSE_FEATUREVALUE_VALUESTATUS']._serialized_start=2346
  _globals['_FEATUREVALUESRESPONSE_FEATUREVALUE_VALUESTATUS']._serialized_end=2383
  _globals['_ONTHEFLYDATA']._serialized_start=2385
  _globals['_ONTHEFLYDATA']._serialized_end=2459
  _globals['_VALUE']._serialized_start=2462
  _globals['_VALUE']._serialized_end=2744
  _globals['_ARRAY']._serialized_start=2746
  _globals['_ARRAY']._serialized_end=2818
  _globals['_SERVINGSERVICE']._serialized_start=2821
  _globals['_SERVINGSERVICE']._serialized_end=3135
# @@protoc_insertion_point(module_scope)
