# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/cluster/v2/cluster.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.administration.runtime_configuration.v0 import runtime_config_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_runtime__config__pb2
from _qwak_proto.qwak.administration.runtime_configuration.v0 import network_config_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_network__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,qwak/administration/cluster/v2/cluster.proto\x12\x1eqwak.administration.cluster.v2\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x41qwak/administration/runtime_configuration/v0/runtime_config.proto\x1a\x41qwak/administration/runtime_configuration/v0/network_config.proto\"\xbb\x01\n\x07\x43luster\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12K\n\rconfiguration\x18\x03 \x01(\x0b\x32\x34.qwak.administration.cluster.v2.ClusterConfiguration\x12I\n\x10\x63luster_metadata\x18\x04 \x01(\x0b\x32/.qwak.administration.cluster.v2.ClusterMetadata\"\xa5\x01\n\x0f\x43lusterMetadata\x12.\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x02 \x01(\t\x12\x34\n\x10last_modified_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10last_modified_by\x18\x04 \x01(\t\"\xb1\x02\n\x14\x43lusterConfiguration\x12\\\n\x19self_hosted_configuration\x18\x01 \x01(\x0b\x32\x37.qwak.administration.cluster.v2.SelfHostedConfigurationH\x00\x12^\n\x1aself_service_configuration\x18\x02 \x01(\x0b\x32\x38.qwak.administration.cluster.v2.SelfServiceConfigurationH\x00\x12S\n\x14hybrid_configuration\x18\x03 \x01(\x0b\x32\x33.qwak.administration.cluster.v2.HybridConfigurationH\x00\x42\x06\n\x04type\"n\n\x17SelfHostedConfiguration\x12S\n\x15runtime_configuration\x18\x01 \x01(\x0b\x32\x34.qwak.administration.cluster.v2.RuntimeConfiguration\"o\n\x18SelfServiceConfiguration\x12S\n\x15runtime_configuration\x18\x01 \x01(\x0b\x32\x34.qwak.administration.cluster.v2.RuntimeConfiguration\"j\n\x13HybridConfiguration\x12S\n\x15runtime_configuration\x18\x01 \x01(\x0b\x32\x34.qwak.administration.cluster.v2.RuntimeConfiguration\"\xf2\x01\n\x14RuntimeConfiguration\x12\x61\n\x15runtime_configuration\x18\x01 \x01(\x0b\x32\x42.qwak.administration.runtime_configuration.v0.RuntimeConfiguration\x12w\n\x15network_configuration\x18\x02 \x01(\x0b\x32X.qwak.administration.runtime_configuration.v0.network_config.ClusterNetworkConfiguration\"y\n\x0b\x43lusterSpec\x12\x14\n\x0c\x64isplay_name\x18\x01 \x01(\t\x12T\n\x12\x63onfiguration_spec\x18\x02 \x01(\x0b\x32\x38.qwak.administration.cluster.v2.ClusterConfigurationSpec\"\xc1\x02\n\x18\x43lusterConfigurationSpec\x12`\n\x19self_hosted_configuration\x18\x01 \x01(\x0b\x32;.qwak.administration.cluster.v2.SelfHostedConfigurationSpecH\x00\x12\x62\n\x1aself_service_configuration\x18\x02 \x01(\x0b\x32<.qwak.administration.cluster.v2.SelfServiceConfigurationSpecH\x00\x12W\n\x14hybrid_configuration\x18\x03 \x01(\x0b\x32\x37.qwak.administration.cluster.v2.HybridConfigurationSpecH\x00\x42\x06\n\x04type\"v\n\x1bSelfHostedConfigurationSpec\x12W\n\x15runtime_configuration\x18\x01 \x01(\x0b\x32\x38.qwak.administration.cluster.v2.RuntimeConfigurationSpec\"w\n\x1cSelfServiceConfigurationSpec\x12W\n\x15runtime_configuration\x18\x01 \x01(\x0b\x32\x38.qwak.administration.cluster.v2.RuntimeConfigurationSpec\"r\n\x17HybridConfigurationSpec\x12W\n\x15runtime_configuration\x18\x01 \x01(\x0b\x32\x38.qwak.administration.cluster.v2.RuntimeConfigurationSpec\"\xf6\x01\n\x18RuntimeConfigurationSpec\x12\x61\n\x15runtime_configuration\x18\x01 \x01(\x0b\x32\x42.qwak.administration.runtime_configuration.v0.RuntimeConfiguration\x12w\n\x15network_configuration\x18\x02 \x01(\x0b\x32X.qwak.administration.runtime_configuration.v0.network_config.ClusterNetworkConfiguration\"V\n\x0c\x43lusterState\x12=\n\x05valid\x18\x01 \x01(\x0b\x32,.qwak.administration.cluster.v2.ClusterValidH\x00\x42\x07\n\x05state\"H\n\x0c\x43lusterValid\x12\x38\n\x07\x63luster\x18\x01 \x01(\x0b\x32\'.qwak.administration.cluster.v2.Cluster\"b\n\x0c\x43lusterBrief\x12R\n\x11installation_type\x18\x01 \x01(\x0e\x32\x37.qwak.administration.cluster.v2.ClusterInstallationType*\xbd\x01\n\x17\x43lusterInstallationType\x12%\n!CLUSTER_INSTALLATION_TYPE_INVALID\x10\x00\x12)\n%SELF_HOSTED_CLUSTER_INSTALLATION_TYPE\x10\x01\x12*\n&SELF_SERVICE_CLUSTER_INSTALLATION_TYPE\x10\x02\x12$\n HYBRID_CLUSTER_INSTALLATION_TYPE\x10\x03\x42\xb4\x01\n)com.qwak.ai.administration.api.cluster.v2P\x01Z\x84\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/cluster/v2;cluster_v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.administration.cluster.v2.cluster_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.qwak.ai.administration.api.cluster.v2P\001Z\204\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/cluster/v2;cluster_v2'
  _globals['_CLUSTERINSTALLATIONTYPE']._serialized_start=2807
  _globals['_CLUSTERINSTALLATIONTYPE']._serialized_end=2996
  _globals['_CLUSTER']._serialized_start=248
  _globals['_CLUSTER']._serialized_end=435
  _globals['_CLUSTERMETADATA']._serialized_start=438
  _globals['_CLUSTERMETADATA']._serialized_end=603
  _globals['_CLUSTERCONFIGURATION']._serialized_start=606
  _globals['_CLUSTERCONFIGURATION']._serialized_end=911
  _globals['_SELFHOSTEDCONFIGURATION']._serialized_start=913
  _globals['_SELFHOSTEDCONFIGURATION']._serialized_end=1023
  _globals['_SELFSERVICECONFIGURATION']._serialized_start=1025
  _globals['_SELFSERVICECONFIGURATION']._serialized_end=1136
  _globals['_HYBRIDCONFIGURATION']._serialized_start=1138
  _globals['_HYBRIDCONFIGURATION']._serialized_end=1244
  _globals['_RUNTIMECONFIGURATION']._serialized_start=1247
  _globals['_RUNTIMECONFIGURATION']._serialized_end=1489
  _globals['_CLUSTERSPEC']._serialized_start=1491
  _globals['_CLUSTERSPEC']._serialized_end=1612
  _globals['_CLUSTERCONFIGURATIONSPEC']._serialized_start=1615
  _globals['_CLUSTERCONFIGURATIONSPEC']._serialized_end=1936
  _globals['_SELFHOSTEDCONFIGURATIONSPEC']._serialized_start=1938
  _globals['_SELFHOSTEDCONFIGURATIONSPEC']._serialized_end=2056
  _globals['_SELFSERVICECONFIGURATIONSPEC']._serialized_start=2058
  _globals['_SELFSERVICECONFIGURATIONSPEC']._serialized_end=2177
  _globals['_HYBRIDCONFIGURATIONSPEC']._serialized_start=2179
  _globals['_HYBRIDCONFIGURATIONSPEC']._serialized_end=2293
  _globals['_RUNTIMECONFIGURATIONSPEC']._serialized_start=2296
  _globals['_RUNTIMECONFIGURATIONSPEC']._serialized_end=2542
  _globals['_CLUSTERSTATE']._serialized_start=2544
  _globals['_CLUSTERSTATE']._serialized_end=2630
  _globals['_CLUSTERVALID']._serialized_start=2632
  _globals['_CLUSTERVALID']._serialized_end=2704
  _globals['_CLUSTERBRIEF']._serialized_start=2706
  _globals['_CLUSTERBRIEF']._serialized_end=2804
# @@protoc_insertion_point(module_scope)
