# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/audience/v1/audience_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.audience.v1 import audience_pb2 as qwak_dot_audience_dot_v1_dot_audience__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#qwak/audience/v1/audience_api.proto\x12\x10qwak.audience.v1\x1a\x1fqwak/audience/v1/audience.proto\"E\n\x15\x43reateAudienceRequest\x12,\n\x08\x61udience\x18\x01 \x01(\x0b\x32\x1a.qwak.audience.v1.Audience\"-\n\x16\x43reateAudienceResponse\x12\x13\n\x0b\x61udience_id\x18\x01 \x01(\t\"Q\n\x15UpdateAudienceRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12,\n\x08\x61udience\x18\x03 \x01(\x0b\x32\x1a.qwak.audience.v1.Audience\"\x18\n\x16UpdateAudienceResponse\")\n\x12GetAudienceRequest\x12\x13\n\x0b\x61udience_id\x18\x01 \x01(\t\"C\n\x13GetAudienceResponse\x12,\n\x08\x61udience\x18\x01 \x01(\x0b\x32\x1a.qwak.audience.v1.Audience\"\x15\n\x13ListAudienceRequest\"Q\n\x14ListAudienceResponse\x12\x39\n\x10\x61udience_entries\x18\x01 \x03(\x0b\x32\x1f.qwak.audience.v1.AudienceEntry\",\n\x15\x44\x65leteAudienceRequest\x12\x13\n\x0b\x61udience_id\x18\x01 \x01(\t\"\x18\n\x16\x44\x65leteAudienceResponse\".\n\x14SyncAudiencesRequest\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\"\x17\n\x15SyncAudiencesResponse2\xd9\x04\n\x0b\x41udienceAPI\x12\x63\n\x0e\x43reateAudience\x12\'.qwak.audience.v1.CreateAudienceRequest\x1a(.qwak.audience.v1.CreateAudienceResponse\x12\x63\n\x0eUpdateAudience\x12\'.qwak.audience.v1.UpdateAudienceRequest\x1a(.qwak.audience.v1.UpdateAudienceResponse\x12Z\n\x0bGetAudience\x12$.qwak.audience.v1.GetAudienceRequest\x1a%.qwak.audience.v1.GetAudienceResponse\x12]\n\x0cListAudience\x12%.qwak.audience.v1.ListAudienceRequest\x1a&.qwak.audience.v1.ListAudienceResponse\x12\x63\n\x0e\x44\x65leteAudience\x12\'.qwak.audience.v1.DeleteAudienceRequest\x1a(.qwak.audience.v1.DeleteAudienceResponse\x12`\n\rSyncAudiences\x12&.qwak.audience.v1.SyncAudiencesRequest\x1a\'.qwak.audience.v1.SyncAudiencesResponseBE\n\x14\x63om.qwak.audience.v1B\x10\x41udienceAPIProtoP\x01Z\x19qwak/audience/v1;audienceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.audience.v1.audience_api_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024com.qwak.audience.v1B\020AudienceAPIProtoP\001Z\031qwak/audience/v1;audience'
  _globals['_CREATEAUDIENCEREQUEST']._serialized_start=90
  _globals['_CREATEAUDIENCEREQUEST']._serialized_end=159
  _globals['_CREATEAUDIENCERESPONSE']._serialized_start=161
  _globals['_CREATEAUDIENCERESPONSE']._serialized_end=206
  _globals['_UPDATEAUDIENCEREQUEST']._serialized_start=208
  _globals['_UPDATEAUDIENCEREQUEST']._serialized_end=289
  _globals['_UPDATEAUDIENCERESPONSE']._serialized_start=291
  _globals['_UPDATEAUDIENCERESPONSE']._serialized_end=315
  _globals['_GETAUDIENCEREQUEST']._serialized_start=317
  _globals['_GETAUDIENCEREQUEST']._serialized_end=358
  _globals['_GETAUDIENCERESPONSE']._serialized_start=360
  _globals['_GETAUDIENCERESPONSE']._serialized_end=427
  _globals['_LISTAUDIENCEREQUEST']._serialized_start=429
  _globals['_LISTAUDIENCEREQUEST']._serialized_end=450
  _globals['_LISTAUDIENCERESPONSE']._serialized_start=452
  _globals['_LISTAUDIENCERESPONSE']._serialized_end=533
  _globals['_DELETEAUDIENCEREQUEST']._serialized_start=535
  _globals['_DELETEAUDIENCEREQUEST']._serialized_end=579
  _globals['_DELETEAUDIENCERESPONSE']._serialized_start=581
  _globals['_DELETEAUDIENCERESPONSE']._serialized_end=605
  _globals['_SYNCAUDIENCESREQUEST']._serialized_start=607
  _globals['_SYNCAUDIENCESREQUEST']._serialized_end=653
  _globals['_SYNCAUDIENCESRESPONSE']._serialized_start=655
  _globals['_SYNCAUDIENCESRESPONSE']._serialized_end=678
  _globals['_AUDIENCEAPI']._serialized_start=681
  _globals['_AUDIENCEAPI']._serialized_end=1282
# @@protoc_insertion_point(module_scope)
