# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/entities/entity_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.feature_store.entities import entity_pb2 as qwak_dot_feature__store_dot_entities_dot_entity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0qwak/feature_store/entities/entity_service.proto\x12\x1bqwak.feature.store.entities\x1a(qwak/feature_store/entities/entity.proto\"S\n\x13\x43reateEntityRequest\x12<\n\x0b\x65ntity_spec\x18\x01 \x01(\x0b\x32\'.qwak.feature.store.entities.EntitySpec\"f\n\x13UpdateEntityRequest\x12\x11\n\tentity_id\x18\x01 \x01(\t\x12<\n\x0b\x65ntity_spec\x18\x02 \x01(\x0b\x32\'.qwak.feature.store.entities.EntitySpec\"K\n\x14UpdateEntityResponse\x12\x33\n\x06\x65ntity\x18\x01 \x01(\x0b\x32#.qwak.feature.store.entities.Entity\"K\n\x14\x43reateEntityResponse\x12\x33\n\x06\x65ntity\x18\x01 \x01(\x0b\x32#.qwak.feature.store.entities.Entity\")\n\x14GetEntityByIdRequest\x12\x11\n\tentity_id\x18\x01 \x01(\t\"L\n\x15GetEntityByIdResponse\x12\x33\n\x06\x65ntity\x18\x01 \x01(\x0b\x32#.qwak.feature.store.entities.Entity\"-\n\x16GetEntityByNameRequest\x12\x13\n\x0b\x65ntity_name\x18\x01 \x01(\t\"N\n\x17GetEntityByNameResponse\x12\x33\n\x06\x65ntity\x18\x01 \x01(\x0b\x32#.qwak.feature.store.entities.Entity\"(\n\x13\x44\x65leteEntityRequest\x12\x11\n\tentity_id\x18\x01 \x01(\t\"\x16\n\x14\x44\x65leteEntityResponse\"\x15\n\x13ListEntitiesRequest\"M\n\x14ListEntitiesResponse\x12\x35\n\x08\x65ntities\x18\x01 \x03(\x0b\x32#.qwak.feature.store.entities.Entity2\xd9\x05\n\rEntityService\x12s\n\x0c\x43reateEntity\x12\x30.qwak.feature.store.entities.CreateEntityRequest\x1a\x31.qwak.feature.store.entities.CreateEntityResponse\x12s\n\x0cUpdateEntity\x12\x30.qwak.feature.store.entities.UpdateEntityRequest\x1a\x31.qwak.feature.store.entities.UpdateEntityResponse\x12s\n\x0c\x44\x65leteEntity\x12\x30.qwak.feature.store.entities.DeleteEntityRequest\x1a\x31.qwak.feature.store.entities.DeleteEntityResponse\x12v\n\rGetEntityById\x12\x31.qwak.feature.store.entities.GetEntityByIdRequest\x1a\x32.qwak.feature.store.entities.GetEntityByIdResponse\x12|\n\x0fGetEntityByName\x12\x33.qwak.feature.store.entities.GetEntityByNameRequest\x1a\x34.qwak.feature.store.entities.GetEntityByNameResponse\x12s\n\x0cListEntities\x12\x30.qwak.feature.store.entities.ListEntitiesRequest\x1a\x31.qwak.feature.store.entities.ListEntitiesResponseB]\n(com.qwak.ai.feature.store.management.apiP\x01Z/qwak/featurestore/entities;featurestoreentitiesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.feature_store.entities.entity_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(com.qwak.ai.feature.store.management.apiP\001Z/qwak/featurestore/entities;featurestoreentities'
  _globals['_CREATEENTITYREQUEST']._serialized_start=123
  _globals['_CREATEENTITYREQUEST']._serialized_end=206
  _globals['_UPDATEENTITYREQUEST']._serialized_start=208
  _globals['_UPDATEENTITYREQUEST']._serialized_end=310
  _globals['_UPDATEENTITYRESPONSE']._serialized_start=312
  _globals['_UPDATEENTITYRESPONSE']._serialized_end=387
  _globals['_CREATEENTITYRESPONSE']._serialized_start=389
  _globals['_CREATEENTITYRESPONSE']._serialized_end=464
  _globals['_GETENTITYBYIDREQUEST']._serialized_start=466
  _globals['_GETENTITYBYIDREQUEST']._serialized_end=507
  _globals['_GETENTITYBYIDRESPONSE']._serialized_start=509
  _globals['_GETENTITYBYIDRESPONSE']._serialized_end=585
  _globals['_GETENTITYBYNAMEREQUEST']._serialized_start=587
  _globals['_GETENTITYBYNAMEREQUEST']._serialized_end=632
  _globals['_GETENTITYBYNAMERESPONSE']._serialized_start=634
  _globals['_GETENTITYBYNAMERESPONSE']._serialized_end=712
  _globals['_DELETEENTITYREQUEST']._serialized_start=714
  _globals['_DELETEENTITYREQUEST']._serialized_end=754
  _globals['_DELETEENTITYRESPONSE']._serialized_start=756
  _globals['_DELETEENTITYRESPONSE']._serialized_end=778
  _globals['_LISTENTITIESREQUEST']._serialized_start=780
  _globals['_LISTENTITIESREQUEST']._serialized_end=801
  _globals['_LISTENTITIESRESPONSE']._serialized_start=803
  _globals['_LISTENTITIESRESPONSE']._serialized_end=880
  _globals['_ENTITYSERVICE']._serialized_start=883
  _globals['_ENTITYSERVICE']._serialized_end=1612
# @@protoc_insertion_point(module_scope)
