# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/batch_job/v1/batch_job_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.user_application.common.v0 import resources_pb2 as qwak_dot_user__application_dot_common_dot_v0_dot_resources__pb2
from _qwak_proto.qwak.batch_job.v1 import batch_job_events_pb2 as qwak_dot_batch__job_dot_v1_dot_batch__job__events__pb2
from _qwak_proto.qwak.administration.authenticated_user.v1 import credentials_pb2 as qwak_dot_administration_dot_authenticated__user_dot_v1_dot_credentials__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)qwak/batch_job/v1/batch_job_service.proto\x12\rqwak.batchjob\x1a\x1fgoogle/protobuf/timestamp.proto\x1a/qwak/user_application/common/v0/resources.proto\x1a(qwak/batch_job/v1/batch_job_events.proto\x1a;qwak/administration/authenticated_user/v1/credentials.proto\"\xb4\x01\n\x15StartWarmupJobRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x10\n\x08\x62uild_id\x18\x05 \x01(\t\x12\x16\n\x0ewarmup_timeout\x18\x03 \x01(\x05\x12H\n\x19\x62\x61tch_job_deployment_size\x18\x04 \x01(\x0b\x32%.qwak.batchjob.BatchJobDeploymentSize\"B\n\x16StartWarmupJobResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x17\n\x0f\x66\x61ilure_message\x18\x02 \x01(\t\"S\n\x16\x43\x61ncelWarmupJobRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x10\n\x08\x62uild_id\x18\x03 \x01(\t\"C\n\x17\x43\x61ncelWarmupJobResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x17\n\x0f\x66\x61ilure_message\x18\x02 \x01(\t\"\x89\x05\n\x14StartBatchJobRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x10\n\x08\x62uild_id\x18\x0f \x01(\t\x12\x15\n\rsource_bucket\x18\x03 \x01(\t\x12\x1a\n\x12\x64\x65stination_bucket\x18\x04 \x01(\t\x12\x15\n\rsource_folder\x18\x05 \x01(\t\x12\x1a\n\x12\x64\x65stination_folder\x18\x06 \x01(\t\x12H\n\x19\x62\x61tch_job_deployment_size\x18\x07 \x01(\x0b\x32%.qwak.batchjob.BatchJobDeploymentSize\x12\x13\n\x0bjob_timeout\x18\x08 \x01(\x05\x12\x14\n\x0ctask_timeout\x18\t \x01(\x05\x12\x35\n\x0finput_file_type\x18\n \x01(\x0e\x32\x1c.qwak.batchjob.InputFileType\x12\x37\n\x10output_file_type\x18\x0b \x01(\x0e\x32\x1d.qwak.batchjob.OutputFileType\x12\x14\n\x0ctoken_secret\x18\x0c \x01(\t\x12\x15\n\rsecret_secret\x18\r \x01(\t\x12M\n\x1b\x61\x64vanced_deployment_options\x18\x0e \x01(\x0b\x32(.qwak.batchjob.AdvancedDeploymentOptions\x12\x34\n\nparameters\x18\x10 \x03(\x0b\x32 .qwak.batchjob.BatchJobParameter\x12\x39\n\x11\x62\x61tch_job_request\x18\x11 \x01(\x0b\x32\x1e.qwak.batchjob.BatchJobRequest\"\xcb\x01\n\x0f\x42\x61tchJobRequest\x12:\n\rmodel_details\x18\x01 \x01(\x0b\x32#.qwak.batchjob.BatchJobModelDetails\x12\x38\n\x0c\x64\x61ta_details\x18\x02 \x01(\x0b\x32\".qwak.batchjob.BatchJobDataDetails\x12\x42\n\x11\x65xecution_details\x18\x04 \x01(\x0b\x32\'.qwak.batchjob.BatchJobExecutionDetails\":\n\x14\x42\x61tchJobModelDetails\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x0f \x01(\t\"\xe5\x01\n\x13\x42\x61tchJobDataDetails\x12\x36\n\x0bsource_path\x18\x01 \x01(\x0b\x32!.qwak.batchjob.BatchJobSourcePath\x12@\n\x10\x64\x65stination_path\x18\x02 \x01(\x0b\x32&.qwak.batchjob.BatchJobDestinationPath\x12\x14\n\x0ctoken_secret\x18\x0c \x01(\t\x12\x15\n\rsecret_secret\x18\r \x01(\t\x12\'\n\x1fservice_account_json_key_secret\x18\x05 \x01(\t\"y\n\x12\x42\x61tchJobSourcePath\x12\x15\n\rsource_bucket\x18\x01 \x01(\t\x12\x15\n\rsource_folder\x18\x02 \x01(\t\x12\x35\n\x0finput_file_type\x18\x03 \x01(\x0e\x32\x1c.qwak.batchjob.InputFileType\"\x8a\x01\n\x17\x42\x61tchJobDestinationPath\x12\x1a\n\x12\x64\x65stination_bucket\x18\x01 \x01(\t\x12\x1a\n\x12\x64\x65stination_folder\x18\x02 \x01(\t\x12\x37\n\x10output_file_type\x18\x03 \x01(\x0e\x32\x1d.qwak.batchjob.OutputFileType\"\x94\x02\n\x18\x42\x61tchJobExecutionDetails\x12\x13\n\x0bjob_timeout\x18\x01 \x01(\x05\x12\x14\n\x0ctask_timeout\x18\x02 \x01(\x05\x12H\n\x19\x62\x61tch_job_deployment_size\x18\x03 \x01(\x0b\x32%.qwak.batchjob.BatchJobDeploymentSize\x12M\n\x1b\x61\x64vanced_deployment_options\x18\x04 \x01(\x0b\x32(.qwak.batchjob.AdvancedDeploymentOptions\x12\x34\n\nparameters\x18\x05 \x03(\x0b\x32 .qwak.batchjob.BatchJobParameter\"/\n\x11\x42\x61tchJobParameter\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"S\n\x15StartBatchJobResponse\x12\x10\n\x08\x62\x61tch_id\x18\x01 \x01(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x17\n\x0f\x66\x61ilure_message\x18\x03 \x01(\t\")\n\x15\x43\x61ncelBatchJobRequest\x12\x10\n\x08\x62\x61tch_id\x18\x01 \x01(\t\"B\n\x16\x43\x61ncelBatchJobResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x17\n\x0f\x66\x61ilure_message\x18\x02 \x01(\t\",\n\x18GetBatchJobStatusRequest\x12\x10\n\x08\x62\x61tch_id\x18\x01 \x01(\t\"\xac\x01\n\x19GetBatchJobStatusResponse\x12\x38\n\njob_status\x18\x01 \x01(\x0e\x32$.qwak.batchjob.BatchJobStatusMessage\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x17\n\x0f\x66\x61ilure_message\x18\x03 \x01(\t\x12\x16\n\x0e\x66inished_files\x18\x04 \x01(\x05\x12\x13\n\x0btotal_files\x18\x05 \x01(\x05\",\n\x18GetBatchJobReportRequest\x12\x10\n\x08\x62\x61tch_id\x18\x01 \x01(\t\"a\n\x19GetBatchJobReportResponse\x12\x12\n\nsuccessful\x18\x01 \x01(\x08\x12\x17\n\x0f\x66\x61ilure_message\x18\x02 \x01(\t\x12\x17\n\x0freport_messages\x18\x03 \x03(\t\"`\n\x1dUpdateBatchTasksStatusRequest\x12?\n\x11\x62\x61tch_task_events\x18\x01 \x03(\x0b\x32$.qwak.batchjob.BatchTaskEventMessage\"I\n\x1dUpdateBatchTaskStatusResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x17\n\x0f\x66\x61ilure_message\x18\x02 \x01(\t\"z\n\x19\x41\x64vancedDeploymentOptions\x12\x1b\n\x13\x63ustom_iam_role_arn\x18\x01 \x01(\t\x12\x17\n\x0fpurchase_option\x18\x02 \x01(\t\x12\'\n\x1fservice_account_key_secret_name\x18\x03 \x01(\t\"\x85\x03\n\x16\x42\x61tchJobDeploymentSize\x12\x16\n\x0enumber_of_pods\x18\x01 \x01(\x05\x12\x0f\n\x03\x63pu\x18\x02 \x01(\x02\x42\x02\x18\x01\x12\x19\n\rmemory_amount\x18\x03 \x01(\x05\x42\x02\x18\x01\x12J\n\x0cmemory_units\x18\x04 \x01(\x0e\x32\x30.qwak.batchjob.BatchJobDeploymentSize.MemoryUnitB\x02\x18\x01\x12H\n\rgpu_resources\x18\x05 \x01(\x0b\x32-.qwak.user_application.common.v0.GpuResourcesB\x02\x18\x01\x12`\n\x1c\x63lient_pod_compute_resources\x18\x06 \x01(\x0b\x32:.qwak.user_application.common.v0.ClientPodComputeResources\"/\n\nMemoryUnit\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03MIB\x10\x01\x12\x07\n\x03GIB\x10\x02\x1a\x02\x18\x01\"\x99\x01\n\x15\x42\x61tchJobExecutionSize\x12\x16\n\x0enumber_of_pods\x18\x01 \x01(\x05\x12S\n\x15pod_compute_resources\x18\x02 \x01(\x0b\x32\x34.qwak.user_application.common.v0.PodComputeResources\x12\x13\n\x0btemplate_id\x18\x03 \x01(\t\"Q\n\x14ListBatchJobsRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x10\n\x08\x62uild_id\x18\x03 \x01(\t\"K\n\x15ListBatchJobsResponse\x12\x32\n\nbatch_jobs\x18\x01 \x03(\x0b\x32\x1e.qwak.batchjob.BatchJobDetails\"\x81\x03\n\x0f\x42\x61tchJobDetails\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\t\x12\x38\n\njob_status\x18\x03 \x01(\x0e\x32$.qwak.batchjob.BatchJobStatusMessage\x12.\n\nstart_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x17\n\x0f\x66\x61ilure_message\x18\x06 \x01(\t\x12;\n\x08job_size\x18\x07 \x01(\x0b\x32%.qwak.batchjob.BatchJobDeploymentSizeB\x02\x18\x01\x12\x46\n\x18\x62\x61tch_job_execution_size\x18\x08 \x01(\x0b\x32$.qwak.batchjob.BatchJobExecutionSize\x12\x16\n\x0e\x65nvironment_id\x18\t \x01(\t\"+\n\x19GetBatchJobDetailsRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"y\n\x1aGetBatchJobDetailsResponse\x12\x31\n\tbatch_job\x18\x01 \x01(\x0b\x32\x1e.qwak.batchjob.BatchJobMessage\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x17\n\x0f\x66\x61ilure_message\x18\x03 \x01(\t\"\x84\x04\n\x0f\x42\x61tchJobMessage\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x10\n\x08model_id\x18\x02 \x01(\t\x12\x15\n\tbranch_id\x18\x03 \x01(\tB\x02\x18\x01\x12\x10\n\x08\x62uild_id\x18\x04 \x01(\t\x12.\n\nstart_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x38\n\njob_status\x18\x07 \x01(\x0e\x32$.qwak.batchjob.BatchJobStatusMessage\x12\x15\n\rtotal_records\x18\x08 \x01(\x05\x12\x37\n\x08job_size\x18\t \x01(\x0b\x32%.qwak.batchjob.BatchJobDeploymentSize\x12;\n\x0freport_messages\x18\n \x03(\x0b\x32\".qwak.batchjob.ExecutionReportLine\x12\x43\n\x16\x65xecution_file_details\x18\x0b \x01(\x0b\x32#.qwak.batchjob.ExecutionFileDetails\x12<\n\x0ftask_executions\x18\x0c \x03(\x0b\x32#.qwak.batchjob.TaskExecutionDetails\"M\n\x13\x45xecutionReportLine\x12(\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04line\x18\x02 \x01(\t\"\x95\x02\n\x14\x45xecutionFileDetails\x12\x15\n\rsource_bucket\x18\x01 \x01(\t\x12\x1a\n\x12\x64\x65stination_bucket\x18\x02 \x01(\t\x12\x13\n\x0bsource_path\x18\x03 \x01(\t\x12\x18\n\x10\x64\x65stination_path\x18\x04 \x01(\t\x12\x35\n\x0finput_file_type\x18\x05 \x01(\x0e\x32\x1c.qwak.batchjob.InputFileType\x12\x37\n\x10output_file_type\x18\x06 \x01(\x0e\x32\x1d.qwak.batchjob.OutputFileType\x12\x16\n\x0e\x66inished_files\x18\x07 \x01(\x05\x12\x13\n\x0btotal_files\x18\x08 \x01(\x05\"\xfd\x01\n\x14TaskExecutionDetails\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x35\n\x06status\x18\x02 \x01(\x0e\x32%.qwak.batchjob.BatchTaskStatusMessage\x12.\n\nstart_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0enum_of_records\x18\x05 \x01(\x05\x12\x14\n\x08\x66ilename\x18\x06 \x01(\tB\x02\x18\x01\x12\x11\n\tfilenames\x18\x07 \x03(\t\"d\n$GetBatchJobPreSignedUploadUrlRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x17\n\x0fnumber_of_files\x18\x02 \x01(\x05\x12\x11\n\tfile_type\x18\x03 \x01(\t\"\x98\x01\n%GetBatchJobPreSignedUploadUrlResponse\x12\x12\n\ninput_path\x18\x01 \x01(\t\x12\x13\n\x0boutput_path\x18\x02 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x03 \x01(\t\x12\x0c\n\x04urls\x18\x04 \x03(\t\x12\x0f\n\x07success\x18\x05 \x01(\x08\x12\x17\n\x0f\x66\x61ilure_message\x18\x06 \x01(\t\"8\n&GetBatchJobPreSignedDownloadUrlRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"a\n\'GetBatchJobPreSignedDownloadUrlResponse\x12\x0c\n\x04urls\x18\x01 \x03(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x17\n\x0f\x66\x61ilure_message\x18\x03 \x01(\t\"3\n\x1fGetBatchJobUploadDetailsRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\"\xb4\x01\n GetBatchJobUploadDetailsResponse\x12\x12\n\ninput_path\x18\x01 \x01(\t\x12\x13\n\x0boutput_path\x18\x02 \x01(\t\x12\x0e\n\x06\x62ucket\x18\x03 \x01(\t\x12W\n\x0b\x63redentials\x18\x04 \x01(\x0b\x32\x42.qwak.administration.authenticated_user.v1.AwsTemporaryCredentials\"3\n!GetBatchJobDownloadDetailsRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"\x9b\x01\n\"GetBatchJobDownloadDetailsResponse\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12W\n\x0b\x63redentials\x18\x03 \x01(\x0b\x32\x42.qwak.administration.authenticated_user.v1.AwsTemporaryCredentials\"\xd7\x01\n\x1aUpdateDefaultParamsRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x02 \x01(\t\x12\x46\n\x17\x64\x65\x66\x61ult_deployment_size\x18\x03 \x01(\x0b\x32%.qwak.batchjob.BatchJobDeploymentSize\x12M\n\x1b\x61\x64vanced_deployment_options\x18\x04 \x01(\x0b\x32(.qwak.batchjob.AdvancedDeploymentOptions\"\x1d\n\x1bUpdateDefaultParamsResponse\".\n\x1a\x44\x65leteDefaultParamsRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\"\x1d\n\x1b\x44\x65leteDefaultParamsResponse\"S\n&UpdateTaskIngestedRecordsAmountRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x18\n\x10ingested_records\x18\x02 \x01(\x03\")\n\'UpdateTaskIngestedRecordsAmountResponse\"S\n\x19UpdateTasksDetailsRequest\x12\x36\n\rtasks_details\x18\x01 \x03(\x0b\x32\x1f.qwak.batchjob.BatchTaskDetails\"\x1c\n\x1aUpdateTasksDetailsResponse\"a\n\x10\x42\x61tchTaskDetails\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12<\n\x13input_files_details\x18\x02 \x03(\x0b\x32\x1f.qwak.batchjob.InputFileDetails\" \n\x10InputFileDetails\x12\x0c\n\x04path\x18\x01 \x01(\t*\x81\x01\n\rInputFileType\x12\x1d\n\x19UNDEFINED_INPUT_FILE_TYPE\x10\x00\x12\x17\n\x13\x43SV_INPUT_FILE_TYPE\x10\x01\x12\x1b\n\x17\x46\x45\x41THER_INPUT_FILE_TYPE\x10\x02\x12\x1b\n\x17PARQUET_INPUT_FILE_TYPE\x10\x03*\x86\x01\n\x0eOutputFileType\x12\x1e\n\x1aUNDEFINED_OUTPUT_FILE_TYPE\x10\x00\x12\x18\n\x14\x43SV_OUTPUT_FILE_TYPE\x10\x01\x12\x1c\n\x18\x46\x45\x41THER_OUTPUT_FILE_TYPE\x10\x02\x12\x1c\n\x18PARQUET_OUTPUT_FILE_TYPE\x10\x03*\x8d\x02\n\x15\x42\x61tchJobStatusMessage\x12\x1e\n\x1aUNDEFINED_BATCH_JOB_STATUS\x10\x00\x12\x1e\n\x1a\x42\x41TCH_JOB_COMMITTED_STATUS\x10\x01\x12\x1c\n\x18\x42\x41TCH_JOB_PENDING_STATUS\x10\x02\x12\x1c\n\x18\x42\x41TCH_JOB_RUNNING_STATUS\x10\x03\x12\x1d\n\x19\x42\x41TCH_JOB_FINISHED_STATUS\x10\x04\x12\x1b\n\x17\x42\x41TCH_JOB_FAILED_STATUS\x10\x05\x12\x1e\n\x1a\x42\x41TCH_JOB_CANCELLED_STATUS\x10\x06\x12\x1c\n\x18\x42\x41TCH_JOB_TIMEOUT_STATUS\x10\x07*\x9c\x02\n\x16\x42\x61tchTaskStatusMessage\x12\x1f\n\x1bUNDEFINED_BATCH_TASK_STATUS\x10\x00\x12\x1f\n\x1b\x42\x41TCH_TASK_COMMITTED_STATUS\x10\x01\x12#\n\x1f\x42\x41TCH_TASK_PENDING_START_STATUS\x10\x02\x12\x1d\n\x19\x42\x41TCH_TASK_RUNNING_STATUS\x10\x03\x12\x1e\n\x1a\x42\x41TCH_TASK_FINISHED_STATUS\x10\x04\x12\x1c\n\x18\x42\x41TCH_TASK_FAILED_STATUS\x10\x05\x12\x1f\n\x1b\x42\x41TCH_TASK_CANCELLED_STATUS\x10\x06\x12\x1d\n\x19\x42\x41TCH_TASK_TIMEOUT_STATUS\x10\x07\x32\x9f\x0f\n\x19\x42\x61tchJobManagementService\x12Z\n\rStartBatchJob\x12#.qwak.batchjob.StartBatchJobRequest\x1a$.qwak.batchjob.StartBatchJobResponse\x12]\n\x0e\x43\x61ncelBatchJob\x12$.qwak.batchjob.CancelBatchJobRequest\x1a%.qwak.batchjob.CancelBatchJobResponse\x12]\n\x0eStartWarmupJob\x12$.qwak.batchjob.StartWarmupJobRequest\x1a%.qwak.batchjob.StartWarmupJobResponse\x12`\n\x0f\x43\x61ncelWarmupJob\x12%.qwak.batchjob.CancelWarmupJobRequest\x1a&.qwak.batchjob.CancelWarmupJobResponse\x12\x66\n\x11GetBatchJobStatus\x12\'.qwak.batchjob.GetBatchJobStatusRequest\x1a(.qwak.batchjob.GetBatchJobStatusResponse\x12\x66\n\x11GetBatchJobReport\x12\'.qwak.batchjob.GetBatchJobReportRequest\x1a(.qwak.batchjob.GetBatchJobReportResponse\x12t\n\x16UpdateBatchTasksStatus\x12,.qwak.batchjob.UpdateBatchTasksStatusRequest\x1a,.qwak.batchjob.UpdateBatchTaskStatusResponse\x12Z\n\rListBatchJobs\x12#.qwak.batchjob.ListBatchJobsRequest\x1a$.qwak.batchjob.ListBatchJobsResponse\x12i\n\x12GetBatchJobDetails\x12(.qwak.batchjob.GetBatchJobDetailsRequest\x1a).qwak.batchjob.GetBatchJobDetailsResponse\x12\x8a\x01\n\x1dGetBatchJobPreSignedUploadUrl\x12\x33.qwak.batchjob.GetBatchJobPreSignedUploadUrlRequest\x1a\x34.qwak.batchjob.GetBatchJobPreSignedUploadUrlResponse\x12\x90\x01\n\x1fGetBatchJobPreSignedDownloadUrl\x12\x35.qwak.batchjob.GetBatchJobPreSignedDownloadUrlRequest\x1a\x36.qwak.batchjob.GetBatchJobPreSignedDownloadUrlResponse\x12{\n\x18GetBatchJobUploadDetails\x12..qwak.batchjob.GetBatchJobUploadDetailsRequest\x1a/.qwak.batchjob.GetBatchJobUploadDetailsResponse\x12\x81\x01\n\x1aGetBatchJobDownloadDetails\x12\x30.qwak.batchjob.GetBatchJobDownloadDetailsRequest\x1a\x31.qwak.batchjob.GetBatchJobDownloadDetailsResponse\x12l\n\x13UpdateDefaultParams\x12).qwak.batchjob.UpdateDefaultParamsRequest\x1a*.qwak.batchjob.UpdateDefaultParamsResponse\x12l\n\x13\x44\x65leteDefaultParams\x12).qwak.batchjob.DeleteDefaultParamsRequest\x1a*.qwak.batchjob.DeleteDefaultParamsResponse\x12\x90\x01\n\x1fUpdateTaskIngestedRecordsAmount\x12\x35.qwak.batchjob.UpdateTaskIngestedRecordsAmountRequest\x1a\x36.qwak.batchjob.UpdateTaskIngestedRecordsAmountResponse\x12i\n\x12UpdateTasksDetails\x12(.qwak.batchjob.UpdateTasksDetailsRequest\x1a).qwak.batchjob.UpdateTasksDetailsResponseB.\n\x19\x63om.qwak.ai.batch.job.apiP\x01Z\x0f./;inferencejobb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.batch_job.v1.batch_job_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.qwak.ai.batch.job.apiP\001Z\017./;inferencejob'
  _STARTWARMUPJOBREQUEST.fields_by_name['branch_id']._options = None
  _STARTWARMUPJOBREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _CANCELWARMUPJOBREQUEST.fields_by_name['branch_id']._options = None
  _CANCELWARMUPJOBREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _STARTBATCHJOBREQUEST.fields_by_name['branch_id']._options = None
  _STARTBATCHJOBREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _BATCHJOBDEPLOYMENTSIZE_MEMORYUNIT._options = None
  _BATCHJOBDEPLOYMENTSIZE_MEMORYUNIT._serialized_options = b'\030\001'
  _BATCHJOBDEPLOYMENTSIZE.fields_by_name['cpu']._options = None
  _BATCHJOBDEPLOYMENTSIZE.fields_by_name['cpu']._serialized_options = b'\030\001'
  _BATCHJOBDEPLOYMENTSIZE.fields_by_name['memory_amount']._options = None
  _BATCHJOBDEPLOYMENTSIZE.fields_by_name['memory_amount']._serialized_options = b'\030\001'
  _BATCHJOBDEPLOYMENTSIZE.fields_by_name['memory_units']._options = None
  _BATCHJOBDEPLOYMENTSIZE.fields_by_name['memory_units']._serialized_options = b'\030\001'
  _BATCHJOBDEPLOYMENTSIZE.fields_by_name['gpu_resources']._options = None
  _BATCHJOBDEPLOYMENTSIZE.fields_by_name['gpu_resources']._serialized_options = b'\030\001'
  _LISTBATCHJOBSREQUEST.fields_by_name['branch_id']._options = None
  _LISTBATCHJOBSREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _BATCHJOBDETAILS.fields_by_name['job_size']._options = None
  _BATCHJOBDETAILS.fields_by_name['job_size']._serialized_options = b'\030\001'
  _BATCHJOBMESSAGE.fields_by_name['branch_id']._options = None
  _BATCHJOBMESSAGE.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _TASKEXECUTIONDETAILS.fields_by_name['filename']._options = None
  _TASKEXECUTIONDETAILS.fields_by_name['filename']._serialized_options = b'\030\001'
  _globals['_INPUTFILETYPE']._serialized_start=7215
  _globals['_INPUTFILETYPE']._serialized_end=7344
  _globals['_OUTPUTFILETYPE']._serialized_start=7347
  _globals['_OUTPUTFILETYPE']._serialized_end=7481
  _globals['_BATCHJOBSTATUSMESSAGE']._serialized_start=7484
  _globals['_BATCHJOBSTATUSMESSAGE']._serialized_end=7753
  _globals['_BATCHTASKSTATUSMESSAGE']._serialized_start=7756
  _globals['_BATCHTASKSTATUSMESSAGE']._serialized_end=8040
  _globals['_STARTWARMUPJOBREQUEST']._serialized_start=246
  _globals['_STARTWARMUPJOBREQUEST']._serialized_end=426
  _globals['_STARTWARMUPJOBRESPONSE']._serialized_start=428
  _globals['_STARTWARMUPJOBRESPONSE']._serialized_end=494
  _globals['_CANCELWARMUPJOBREQUEST']._serialized_start=496
  _globals['_CANCELWARMUPJOBREQUEST']._serialized_end=579
  _globals['_CANCELWARMUPJOBRESPONSE']._serialized_start=581
  _globals['_CANCELWARMUPJOBRESPONSE']._serialized_end=648
  _globals['_STARTBATCHJOBREQUEST']._serialized_start=651
  _globals['_STARTBATCHJOBREQUEST']._serialized_end=1300
  _globals['_BATCHJOBREQUEST']._serialized_start=1303
  _globals['_BATCHJOBREQUEST']._serialized_end=1506
  _globals['_BATCHJOBMODELDETAILS']._serialized_start=1508
  _globals['_BATCHJOBMODELDETAILS']._serialized_end=1566
  _globals['_BATCHJOBDATADETAILS']._serialized_start=1569
  _globals['_BATCHJOBDATADETAILS']._serialized_end=1798
  _globals['_BATCHJOBSOURCEPATH']._serialized_start=1800
  _globals['_BATCHJOBSOURCEPATH']._serialized_end=1921
  _globals['_BATCHJOBDESTINATIONPATH']._serialized_start=1924
  _globals['_BATCHJOBDESTINATIONPATH']._serialized_end=2062
  _globals['_BATCHJOBEXECUTIONDETAILS']._serialized_start=2065
  _globals['_BATCHJOBEXECUTIONDETAILS']._serialized_end=2341
  _globals['_BATCHJOBPARAMETER']._serialized_start=2343
  _globals['_BATCHJOBPARAMETER']._serialized_end=2390
  _globals['_STARTBATCHJOBRESPONSE']._serialized_start=2392
  _globals['_STARTBATCHJOBRESPONSE']._serialized_end=2475
  _globals['_CANCELBATCHJOBREQUEST']._serialized_start=2477
  _globals['_CANCELBATCHJOBREQUEST']._serialized_end=2518
  _globals['_CANCELBATCHJOBRESPONSE']._serialized_start=2520
  _globals['_CANCELBATCHJOBRESPONSE']._serialized_end=2586
  _globals['_GETBATCHJOBSTATUSREQUEST']._serialized_start=2588
  _globals['_GETBATCHJOBSTATUSREQUEST']._serialized_end=2632
  _globals['_GETBATCHJOBSTATUSRESPONSE']._serialized_start=2635
  _globals['_GETBATCHJOBSTATUSRESPONSE']._serialized_end=2807
  _globals['_GETBATCHJOBREPORTREQUEST']._serialized_start=2809
  _globals['_GETBATCHJOBREPORTREQUEST']._serialized_end=2853
  _globals['_GETBATCHJOBREPORTRESPONSE']._serialized_start=2855
  _globals['_GETBATCHJOBREPORTRESPONSE']._serialized_end=2952
  _globals['_UPDATEBATCHTASKSSTATUSREQUEST']._serialized_start=2954
  _globals['_UPDATEBATCHTASKSSTATUSREQUEST']._serialized_end=3050
  _globals['_UPDATEBATCHTASKSTATUSRESPONSE']._serialized_start=3052
  _globals['_UPDATEBATCHTASKSTATUSRESPONSE']._serialized_end=3125
  _globals['_ADVANCEDDEPLOYMENTOPTIONS']._serialized_start=3127
  _globals['_ADVANCEDDEPLOYMENTOPTIONS']._serialized_end=3249
  _globals['_BATCHJOBDEPLOYMENTSIZE']._serialized_start=3252
  _globals['_BATCHJOBDEPLOYMENTSIZE']._serialized_end=3641
  _globals['_BATCHJOBDEPLOYMENTSIZE_MEMORYUNIT']._serialized_start=3594
  _globals['_BATCHJOBDEPLOYMENTSIZE_MEMORYUNIT']._serialized_end=3641
  _globals['_BATCHJOBEXECUTIONSIZE']._serialized_start=3644
  _globals['_BATCHJOBEXECUTIONSIZE']._serialized_end=3797
  _globals['_LISTBATCHJOBSREQUEST']._serialized_start=3799
  _globals['_LISTBATCHJOBSREQUEST']._serialized_end=3880
  _globals['_LISTBATCHJOBSRESPONSE']._serialized_start=3882
  _globals['_LISTBATCHJOBSRESPONSE']._serialized_end=3957
  _globals['_BATCHJOBDETAILS']._serialized_start=3960
  _globals['_BATCHJOBDETAILS']._serialized_end=4345
  _globals['_GETBATCHJOBDETAILSREQUEST']._serialized_start=4347
  _globals['_GETBATCHJOBDETAILSREQUEST']._serialized_end=4390
  _globals['_GETBATCHJOBDETAILSRESPONSE']._serialized_start=4392
  _globals['_GETBATCHJOBDETAILSRESPONSE']._serialized_end=4513
  _globals['_BATCHJOBMESSAGE']._serialized_start=4516
  _globals['_BATCHJOBMESSAGE']._serialized_end=5032
  _globals['_EXECUTIONREPORTLINE']._serialized_start=5034
  _globals['_EXECUTIONREPORTLINE']._serialized_end=5111
  _globals['_EXECUTIONFILEDETAILS']._serialized_start=5114
  _globals['_EXECUTIONFILEDETAILS']._serialized_end=5391
  _globals['_TASKEXECUTIONDETAILS']._serialized_start=5394
  _globals['_TASKEXECUTIONDETAILS']._serialized_end=5647
  _globals['_GETBATCHJOBPRESIGNEDUPLOADURLREQUEST']._serialized_start=5649
  _globals['_GETBATCHJOBPRESIGNEDUPLOADURLREQUEST']._serialized_end=5749
  _globals['_GETBATCHJOBPRESIGNEDUPLOADURLRESPONSE']._serialized_start=5752
  _globals['_GETBATCHJOBPRESIGNEDUPLOADURLRESPONSE']._serialized_end=5904
  _globals['_GETBATCHJOBPRESIGNEDDOWNLOADURLREQUEST']._serialized_start=5906
  _globals['_GETBATCHJOBPRESIGNEDDOWNLOADURLREQUEST']._serialized_end=5962
  _globals['_GETBATCHJOBPRESIGNEDDOWNLOADURLRESPONSE']._serialized_start=5964
  _globals['_GETBATCHJOBPRESIGNEDDOWNLOADURLRESPONSE']._serialized_end=6061
  _globals['_GETBATCHJOBUPLOADDETAILSREQUEST']._serialized_start=6063
  _globals['_GETBATCHJOBUPLOADDETAILSREQUEST']._serialized_end=6114
  _globals['_GETBATCHJOBUPLOADDETAILSRESPONSE']._serialized_start=6117
  _globals['_GETBATCHJOBUPLOADDETAILSRESPONSE']._serialized_end=6297
  _globals['_GETBATCHJOBDOWNLOADDETAILSREQUEST']._serialized_start=6299
  _globals['_GETBATCHJOBDOWNLOADDETAILSREQUEST']._serialized_end=6350
  _globals['_GETBATCHJOBDOWNLOADDETAILSRESPONSE']._serialized_start=6353
  _globals['_GETBATCHJOBDOWNLOADDETAILSRESPONSE']._serialized_end=6508
  _globals['_UPDATEDEFAULTPARAMSREQUEST']._serialized_start=6511
  _globals['_UPDATEDEFAULTPARAMSREQUEST']._serialized_end=6726
  _globals['_UPDATEDEFAULTPARAMSRESPONSE']._serialized_start=6728
  _globals['_UPDATEDEFAULTPARAMSRESPONSE']._serialized_end=6757
  _globals['_DELETEDEFAULTPARAMSREQUEST']._serialized_start=6759
  _globals['_DELETEDEFAULTPARAMSREQUEST']._serialized_end=6805
  _globals['_DELETEDEFAULTPARAMSRESPONSE']._serialized_start=6807
  _globals['_DELETEDEFAULTPARAMSRESPONSE']._serialized_end=6836
  _globals['_UPDATETASKINGESTEDRECORDSAMOUNTREQUEST']._serialized_start=6838
  _globals['_UPDATETASKINGESTEDRECORDSAMOUNTREQUEST']._serialized_end=6921
  _globals['_UPDATETASKINGESTEDRECORDSAMOUNTRESPONSE']._serialized_start=6923
  _globals['_UPDATETASKINGESTEDRECORDSAMOUNTRESPONSE']._serialized_end=6964
  _globals['_UPDATETASKSDETAILSREQUEST']._serialized_start=6966
  _globals['_UPDATETASKSDETAILSREQUEST']._serialized_end=7049
  _globals['_UPDATETASKSDETAILSRESPONSE']._serialized_start=7051
  _globals['_UPDATETASKSDETAILSRESPONSE']._serialized_end=7079
  _globals['_BATCHTASKDETAILS']._serialized_start=7081
  _globals['_BATCHTASKDETAILS']._serialized_end=7178
  _globals['_INPUTFILEDETAILS']._serialized_start=7180
  _globals['_INPUTFILEDETAILS']._serialized_end=7212
  _globals['_BATCHJOBMANAGEMENTSERVICE']._serialized_start=8043
  _globals['_BATCHJOBMANAGEMENTSERVICE']._serialized_end=9994
# @@protoc_insertion_point(module_scope)
